<?php
/**
 * "comments.php"
 * This template is used for rendering post's comment(s).
 *
 * @package tantyyellow
 */

$tantyyellow_comment_form_args_for_comments = array(
	'id_form'              => 'comment-form',

	'id_submit'            => 'comment-form-submit-field',

	// The title when leaving a comment to a post.
	'title_reply'          => '
								<span class="font-family_subheading_level' . ( ( 'ja' === get_locale() ) ? ' font_weight_bold' : '' ) . ' focusable_elem" aria-label="' . esc_attr__( 'Comment form title named: "Leave A Comment"', 'tantyyellow' ) . '" tabindex="0">' .
									esc_html__( 'LEAVE A COMMENT', 'tantyyellow' ) .
								'</span>
							',

	// The title when replying to a comment.
	'title_reply_to'       => '
								<span class="font-family_subheading_level' . ( ( 'ja' === get_locale() ) ? ' font_weight_bold' : '' ) . ' focusable_elem" aria-label="' . esc_attr__( 'Comment form title named: "Reply to the author"', 'tantyyellow' ) . '" tabindex="0">' .
									esc_html__( 'REPLY', 'tantyyellow' ) . ' ' .
									'<i class="fas fa-long-arrow-alt-right"></i> ' .
									'<span class="comment_author_name_to_be_replied">%s</span>
								</span>
							',

	'comment_field'        => '
								<p class="comment-form-comment">
									<textarea name="comment" cols="35" rows="5" aria-required="true" aria-label="' . esc_attr__( 'Write content in this comment reply text field', 'tantyyellow' ) . '"></textarea>
								</p>
							',

	'cancel_reply_link'    => esc_html__( 'Cancel Comment', 'tantyyellow' ),

	'label_submit'         => esc_html__( 'Send', 'tantyyellow' ),

	'must_log_in'          => '
								<p class="must-log-in">' .
									sprintf(
										/* translators: %s: The link URL to the login page. */
										esc_html__( 'Please log in to leave a comment.', 'tantyyellow' ) .
										'<a href="%s" class="font-family_subheading_level" aria-label="' . esc_attr__( 'In order to leave a comment, you must click this link to the login form and log in', 'tantyyellow' ) . '">' .
											esc_html__( 'Log In', 'tantyyellow' ) .
										'</a>',
										wp_login_url( get_permalink() )
									) .
								'</p>
							',

	'logged_in_as'         => '
								<p class="logged-in-as">' .
									sprintf(
										/* translators: %1$s: User name who is logging in %2$s: The link URL to the logout page. */
										'<span class="author-name focusable_elem" aria-label="' .
											sprintf(
												/* translators: %s: User name who is logging in. */
												esc_attr__( 'Logged in as %s', 'tantyyellow' ),
												$user_identity
											) .
										'" tabindex="0">
											<a style="font-weight: bold;">- %1$s - </a>' .
											esc_html__( ' is logging in.', 'tantyyellow' ) .
										'</span>
										<span class="log-out-btn">
											<a class="font-family_subheading_level" href="%2$s" title="Log out of this account" role="button" aria-label="' . esc_attr__( 'Click this "Log out" button to log out', 'tantyyellow' ) . '">' .
												esc_html__( 'Log Out', 'tantyyellow' ) .
											'</a>
										</span>',
										$user_identity,
										wp_logout_url( get_permalink() )
									) .
								'</p>
							',

	'comment_notes_before' => '',

	'comment_notes_after'  => '',

	'fields'               => array(

		'author' => '
						<p class="comment-form-author">' .
							'<label for="comment-form-author-field">' . esc_html__( 'Name', 'tantyyellow' ) . '</label> ' .
							( $req ? '<span class="required">*</span>' : '' ) .
							'<input id="comment-form-author-field" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" aria-required="true" aria-label="' . esc_attr__( 'Write your name in this field when leaving comment', 'tantyyellow' ) . '" />
						</p>
					',

		'email'  => '
						<p class="comment-form-email">
							<label for="comment-form-email-field">' . esc_html__( 'Email', 'tantyyellow' ) . '</label> ' .
							( $req ? '<span class="required">*</span>' : '' ) .
							'<input id="comment-form-email-field" name="email" type="text" value="' . esc_attr( $commenter['comment_author_email'] ) . '" size="30" aria-required="true" aria-label="' . esc_attr__( 'Write your email address in this field when leaving comment', 'tantyyellow' ) . '" />
						</p>
					',

		'url'    => '',
	),
);



$tantyyellow_comments_pagination_args_for_comments = array(
	'prev_text' => '&laquo; ' . esc_html__( 'Newer', 'tantyyellow' ),
	'next_text' => esc_html__( 'Older', 'tantyyellow' ) . ' &raquo;',
);

/* Callback function for customizing wp_list_comments() of the comments list */
/**
 * Define callback function for the parameter "callback" of array "$tantyyellow_comments_list_args_for_comments".
 *
 * @param WP_Comment $comment Comment object.
 * @param array      $args    An array of arguments.
 * @param int        $depth   Depth.
 */
function tantyyellow_wp_list_comments_callback( $comment, $args, $depth ) {
	?>

	<li <?php comment_class( empty( $args['has_children'] ) ? 'each-comment' : 'each-comment parent' ); ?> id="each-comment-<?php comment_ID(); ?>">

		<div id="comment-<?php comment_ID(); ?>-wrapper" class="each-comment-wrapper">

			<div class="each-comment-meta clearfix">

				<div class="each-comment-meta-avatar">
					<?php echo ( 0 !== $args['avatar_size'] ) ? wp_kses_post( get_avatar( $comment, $args['avatar_size'] ) ) : ''; ?>
				</div>

				<!-- Each comment meta list -->
				<ul class="each-comment-meta-list">

					<!-- Each comment meta title -->
					<?php
					$comment_id           = $comment->comment_ID;
					$comment_author       = get_comment_author( $comment_id );
					$comment_id_parent    = $comment->comment_parent;
					$comment_replied_date = sprintf(
						/* translators: %1$s: comment replied date / %2$s: comment replied time. */
						esc_html( '%1$s - %2$s' ),
						// Admin Panel's 'Date Format' is applied if get_comment_date(), get_comment_time() has no parameter.
						esc_html( get_comment_date() ),
						esc_html( get_comment_time() )
					);
					?>
					<li class="each-comment-meta-title focusable_elem" aria-label="
						<?php
						printf(
							/* translators: %1$s: comment author's name / %2$s: author's name to be replied / %3$s: comment replied date. */
							esc_attr__( 'Comment replied from %1$s to %2$s was posted: %3$s', 'tantyyellow' ),
							esc_attr( $comment_author ),
							( 2 <= $comment_id_parent ) ?
								esc_attr( get_comment_author( $comment_id_parent ) ) :
								esc_attr__( 'This', 'tantyyellow' ) . ' ' . esc_attr__( 'Post', 'tantyyellow' ),
							esc_attr( $comment_replied_date )
						);
						?>
					" tabindex="0">

						<span>
							<?php
							echo esc_html( $comment_author );
							echo ' <i class="fas fa-long-arrow-alt-right"></i> ';
							echo ( 2 <= $comment_id_parent ) ?
								esc_html( get_comment_author( $comment_id_parent ) ) :
								'<span>' . esc_html__( 'This', 'tantyyellow' ) . ' ' . esc_html__( 'Post', 'tantyyellow' ) . '</span>';
							?>
						</span>

						<?php
						if ( '0' === $comment->comment_approved ) :
							?>
							<span class="each-comment-meta-awaiting-moderation focusable_elem" aria-label="<?php echo esc_attr__( 'Your comment is awaiting moderation', 'tantyyellow' ); ?>" tabindex="0"><?php echo esc_html__( 'Your comment is awaiting moderation.', 'tantyyellow' ); ?>...</span>
							<?php
						endif;
						?>

					</li>

					<!-- Each comment meta date -->
					<li class="each-comment-meta-date">
						<span>
							<?php
							echo esc_html( $comment_replied_date );
							?>
						</span>
					</li>

				</ul>

			</div><!-- /.each-comment-meta -->

			<!-- Each comment main -->
			<div class="each-comment-main">

				<!-- Each comment meta content -->
				<div class="each-comment-main-content">
					<?php comment_text(); ?>
				</div>

			</div>

			<!-- Each comment reply -->
			<div class="each-comment-reply">
				<span>
					<?php
					comment_reply_link(
						array_merge(
							$args,
							array(
								'reply_text' => esc_html__( 'Reply', 'tantyyellow' ),
								'login_text' => esc_html__( 'Log in to Reply.', 'tantyyellow' ),
								'depth'      => $depth,
								'max_depth'  => $args['max_depth'],
							)
						)
					);
					?>
				</span>

				<?php
				if ( is_user_logged_in() ) {
					edit_comment_link( esc_html__( 'Edit', 'tantyyellow' ), '<span>', '</span>' );
				}
				?>
			</div>

		</div><!-- /.each-comment-wrapper -->

	</li>
	<?php
}

/* Callback function for customizing wp_list_comments() of the pingbacks & trackbacks list */
/**
 * Define callback function for the parameter "callback" of array "$tantyyellow_pings_trackbacks_list_args_for_comments".
 *
 * @param WP_Comment $comment Comment object.
 * @param array      $args    An array of arguments.
 * @param int        $depth   Depth.
 */
function tantyyellow_wp_list_comments_pingbacks_trackbacks_callback( $comment, $args, $depth ) {

	?>
	<li id="comment-<?php comment_ID(); ?>" <?php comment_class( '', $comment ); ?>>

		<?php
		$comment_classes_array = get_comment_class();
		if ( in_array( 'trackback', $comment_classes_array, true ) ) {
			?>
			<p class="ping_track_header"><?php esc_html_e( 'Trackback', 'tantyyellow' ); ?></p>
			<?php
		} elseif ( in_array( 'pingback', $comment_classes_array, true ) ) {
			?>
			<p class="ping_track_header"><?php esc_html_e( 'Pingback', 'tantyyellow' ); ?></p>
			<?php
		}

		?>
		<div class="comment-body<?php echo ( is_user_logged_in() ) ? ' is_user_logged_in' : ''; ?>">
			<p><?php comment_author_link( $comment ); ?></p>
			<?php
			if ( is_user_logged_in() ) {
				edit_comment_link( esc_html__( 'Edit', 'tantyyellow' ), '<span class="edit-link">', '</span>' );
			}
			?>
		</div>
		<?php

		// Closing list tag will be automatically added, so don't write it.
}



// Get the number of all comments including comments, pingbacks & trackbacks.
$tantyyellow_all_comments_count = get_comments(
	array(
		'status'  => 'approve',
		'post_id' => get_the_ID(),
		'type'    => 'all',
		'count'   => true,
	)
);

// Get the number of comments.
$tantyyellow_comments_count_for_comments = get_comments(
	array(
		'status'  => 'approve',
		'post_id' => get_the_ID(), // No need to escape.
		'type'    => 'comment',
		'count'   => true,
	)
);

// Get the number of pingbacks & trackbacks.
$tantyyellow_comments_count_for_pings_trackbacks = get_comments(
	array(
		'status'  => 'approve',
		'post_id' => get_the_ID(), // No need to escape.
		'type'    => 'pings',
		'count'   => true,
	)
);



if ( comments_open() || ( 0 < $tantyyellow_comments_count_for_pings_trackbacks ) ) :
	?>
	<div id="<?php echo ( is_single() ) ? 'each-post-comment' : 'each-page-comment'; ?>" class="focusable_elem" aria-label="<?php echo esc_attr__( 'This is the comment section for this post', 'tantyyellow' ); ?>" tabindex="0">

		<div class="comment-wrapper">

			<?php
			/**
			 * Comment Form & Comments List in a post page or a static page.
			 * - Only when comments are allowed ( If "Allow Comments" is checked in the "Discussion" settings in the post/page editting page ),
			 *   Comment Form & Comments List will be active and displayed.
			 */
			if ( comments_open() ) :

				if ( 'open' === $post->comment_status ) : // "$post->comment_status" is string.
					?>
					<div class="comment-form-wrapper focusable_elem" aria-label="<?php echo esc_attr__( 'This is a comment form for this post', 'tantyyellow' ); ?>" tabindex="0">
						<?php comment_form( $tantyyellow_comment_form_args_for_comments ); ?>
					</div>
					<?php
				endif;
				?>

				<!-- '#comments' is recommended to add -->
				<div id="comments" class="comment-each-item">

					<button type="button" id="comments_header" class="comment-each-item-list-title font-family_subheading_level<?php echo ( 'ja' === get_locale() ) ? ' font_weight_bold' : ''; ?>" aria-label="<?php echo esc_attr__( 'Click this title to open or close the list of all comments that belong to this post', 'tantyyellow' ); ?>">
						<?php
						echo esc_html__( 'Comments List', 'tantyyellow' ) . ' ( ' . esc_html( $tantyyellow_comments_count_for_comments ) . ' )';
						?>
					</button>

					<div class="comment-each-item-list">

						<ol class="comment-each-item-list-contents">

							<?php
							/**
							 * Parameters 'max_depth', 'per_page', & 'reverse_top_level' shouldn't be set
							 * so that a user can change the settings in the "Admin Panel => Discussion Settings".
							 *
							 * 'reverse_top_level' => Defines the order of comments from newest(true)/oldest(false) within each page.
							 *                        In other words, the order of pages don't change.
							 *                        For instance, even if "true(newest)" is set, when comments are sorted in order from oldest,
							 *                        the first page contains the older ones, while the last page contains the older ones.
							 *
							 * @link https://developer.wordpress.org/reference/functions/wp_list_comments/ wp_list_comments()
							 */
							$tantyyellow_comments_list_args_for_comments = array(
								'style'            => 'ol',
								'callback'         => 'tantyyellow_wp_list_comments_callback',
								'type'             => 'comment',
								'reply_text'       => esc_html__( 'Reply', 'tantyyellow' ),
								'avatar_size'      => 48,
								'reverse_children' => false,  // To list newer children comments first.
								'short_ping'       => false, /* @since 3.6 */
								'echo'             => true, /* boolean, default is true */
							);

							$tantyyellow_all_comments_for_comments = get_comments(
								array(
									'status'  => 'approve',
									'post_id' => get_the_ID(),
									'type'    => 'comment',
								)
							);

							/* Comments loop */
							if ( 0 < $tantyyellow_comments_count_for_comments ) :

								wp_list_comments( $tantyyellow_comments_list_args_for_comments, $tantyyellow_all_comments_for_comments );

							else :
								?>
								<li><?php esc_html_e( 'There is no comment.', 'tantyyellow' ); ?></li>
								<?php
							endif;
							?>

						</ol>

						<?php
						/**
						 * Get the number of comments ( not including pinbacks & trackbacks ).
						 *
						 * @link https://developer.wordpress.org/reference/functions/get_comment_pages_count/ get_comment_pages_count()
						 * @link https://developer.wordpress.org/reference/functions/get_comments/            get_comments()
						 */
						if ( 1 < get_comment_pages_count( $tantyyellow_all_comments_for_comments ) ) :
							?>
							<div class="comment-each-item-list-pagination-wrapper">
								<p class="comment-each-item-list-pagination font-family_subheading_level">
									<?php paginate_comments_links( $tantyyellow_comments_pagination_args_for_comments ); ?>
								</p>
								<p class="comment-each-item-list-pagination-desc">( <?php esc_html_e( 'Comments', 'tantyyellow' ); ?> )</p>
							</div>
							<?php
						endif;
						?>

					</div><!-- /.comment-each-item-list -->

				</div><!-- /.comment-each-item -->
				<?php

			endif; // End of "if( comments_open() )".



			/**
			 * Pingbacks & Trackbacks List in a post page or a static page.
			 *
			 * - Not divide pingbacks & trackbacks list into several pages and not add the pagenation.
			 * - In other words, even if the comments list is divided into more than two pages,
			 *   pingbacks & trackbacks list doesn't show up in the second page.
			 *
			 * - Pingbacks & trackbacks list is visible even if the number of it is zero, showing the title and no list message.
			 * - "get_query_var( 'cpage' )" retrieves the number of pages of comments.
			 */
			if ( ! ( 1 < get_query_var( 'cpage' ) ) ) :
				?>

				<div id="pings" class="comment-each-item">
					<!-- '#comments' is recommended to add -->

					<button type="button" id="pings_header" class="comment-each-item-list-title font-family_subheading_level<?php echo ( 'ja' === get_locale() ) ? ' font_weight_bold' : ''; ?>" aria-label="<?php echo esc_attr__( 'Click this title to open or close the list of all pingbacks and trackbacks that belong to this post', 'tantyyellow' ); ?>">
						<?php
						echo esc_html__( 'Pingbacks & Trackbacks List', 'tantyyellow' ) .
							' ( ' . esc_html( $tantyyellow_comments_count_for_pings_trackbacks ) . ' )';
						?>
					</button>

					<div class="comment-each-item-list">

						<p>
						<?php
						if ( 0 === $tantyyellow_comments_count_for_pings_trackbacks ) :
							esc_html_e( 'No pingback ( trackback ) is found.', 'tantyyellow' );

						elseif ( 1 === $tantyyellow_comments_count_for_pings_trackbacks ) :
							esc_html_e( '1 pingback ( trackback ) is found.', 'tantyyellow' );

						else :
							echo esc_html( $tantyyellow_comments_count_for_pings_trackbacks );
							esc_html_e( ' pingbacks ( trackbacks ) are found.', 'tantyyellow' );

						endif;
						?>
						</p>

						<ol class="comment-each-item-list-contents">

							<?php
							/* Pingbacks & Trackbacks loop */
							$tantyyellow_comments_list_args_for_pings_trackbacks = array(
								'style'             => 'ol',
								'callback'          => 'tantyyellow_wp_list_comments_pingbacks_trackbacks_callback',
								'type'              => 'pings',
								'avatar_size'       => 48,
								'per_page'          => $tantyyellow_comments_count_for_pings_trackbacks,
								'reverse_top_level' => false, // To list new comments first.
								'short_ping'        => true, // @since 3.6.
								'echo'              => true, // boolean, default is true.
							);

							$tantyyellow_all_comments_for_pings_trackbacks = get_comments(
								array(
									'status'  => 'approve',
									'post_id' => get_the_ID(),
									'type'    => 'pings',
								)
							);

							wp_list_comments( $tantyyellow_comments_list_args_for_pings_trackbacks, $tantyyellow_all_comments_for_pings_trackbacks );
							?>

						</ol>

					</div><!-- /.comment-each-item-list -->

				</div><!-- /.comment-each-item -->

				<?php
			endif;
			?>

		</div><!-- /.comment-wrapper -->

	</div><!-- /.each-post-comment or /.each-page-comment -->
	<?php
endif; // End of "if ( comments_open() )".
