<?php
/**
 * This file defines a new class Tantyyellow_Customizer_Range_Control.
 * In order to show the value of the current range number.
 *
 * @package tantyyellow
 */

// ########################################################################################################################
// ##### In order to show the value of the current number selected by a range slider ######################################
// ########################################################################################################################

/**
 * Define function for action hook "customize_register".
 * - Register theme customizer for class "Tantyyellow_Customizer_Range_Control".
 *
 * @param WP_Customize_Manager $wp_customize Customizer object, which is an instance of the WP_Customize_Manager class.
 */
function tantyyellow_theme_customizer_register_to_extend_class_customize_control( $wp_customize ) {

	if ( ! class_exists( 'Tantyyellow_Customizer_Range_Control' ) && class_exists( 'WP_Customize_Control' ) ) {

		/**
		 * CUSTOMIZE RANGE CONTROL
		 * In order to show the value of the current number selected by a range slider in "Customizer" in "Admin Panel".
		 * - ( Javascript is enqueued in "tantyyellow_customizer_control.js". )
		 *
		 * @see wp-includes/class-walker-nav-menu.php
		 * @see customizer_javascript_apis/tantyyellow_customizer_control.js
		 *
		 * @link https://w3guy.com/wordpress-customizer-range-control-selected-indicator/ "Range Control with Selected Value Indicator"
		 */
		class Tantyyellow_Customizer_Range_Control extends WP_Customize_Control {

			/**
			 * Public variable for a type 'tantyyellow_custom_range'.
			 *
			 * @var string
			 */
			public $type = 'tantyyellow_custom_range';

			/**
			 * Public function to render the value of input number in a range slider.
			 *
			 * @return void
			 */
			public function render_content() {
				?>
				<label>
					<?php
					if ( ! empty( $this->label ) ) :
						?>
						<span class="customize-control-title">
							<?php echo esc_html( $this->label ); ?>
						</span>
						<?php
					endif;
					?>
					<div class="cs-range-value-wrapper">
						<span id="cs-range-value"><?php echo esc_html( $this->value() ); ?></span>
						<span class="range_num_text_for_custom_excerpt_length"><?php echo esc_html__( ' words(letters)', 'tantyyellow' ); ?></span>
						<span class="range_num_text_for_posts_per_page"><?php echo esc_html__( ' posts', 'tantyyellow' ); ?></span>
					</div>
					<input data-input-type="range" type="range" <?php $this->input_attrs(); ?> value="<?php echo esc_attr( $this->value() ); ?>" <?php $this->link(); ?>>
					<?php
					if ( ! empty( $this->description ) ) :
						?>
						<span class="description customize-control-description">
							<?php echo esc_html( $this->description ); ?>
						</span>
						<?php
					endif;
					?>
				</label>
				<?php
			}
		}
	}
}
add_action( 'customize_register', 'tantyyellow_theme_customizer_register_to_extend_class_customize_control' );
