<?php
/**
 * This file contains a set of functions in order to define 'Contextual Helps' at 'Admin Panel'.
 *
 * @package tantyyellow
 */

// ########################################################################################################################
// ##### Functions in order to define 'Contextual Helps' at 'Admin Panel' #################################################
// ########################################################################################################################

/**
 * Define 'Contextual Helps' at 'Admin Panel'
 *
 * @link https://www.webprofessional.jp/wordpress-contextual-help-screens
 * @link https://codex.wordpress.org/Plugin_API/Admin_Screen_Reference
 */
function tantyyellow_add_contextual_helps() {

	/* ===== In order to get the current screen object ========================================== */
	$current_screen = get_current_screen();

	/* ===== Common Helps ======================================================================= */

	/* ----- Help : Theme Template Files -------------------------------------------------- */
	$current_screen->add_help_tab(
		array(
			'id'      => 'tantyyellow_help_theme_template_files',
			'title'   => esc_html__( 'Theme Templates', 'tantyyellow' ),
			'content' =>

				'<div>' .

					'<ol>' .

						'<li>' .
							'<h4 style="margin-bottom: 0;"><span style="font-weight: 900;">' . esc_html__( '"Full Width Page" Template(with Sidebar)', 'tantyyellow' ) . '</span></h4>' .
							'<p style="margin-top: 0; margin-bottom: 0;">' .
							esc_html__( 'This is designed to create a full width page with a widgets sidebar at the right. In the website\'s content area, there is no styles.', 'tantyyellow' ) .
							'</p>' .
						'</li>' .

						'<li>' .
							'<h4 style="margin-bottom: 0;"><span style="font-weight: 900;">' . esc_html__( '"Full Width Page" Template(No Sidebar)', 'tantyyellow' ) . '</span></h4>' .
							'<p style="margin-top: 0; margin-bottom: 0;">' .
							esc_html__( 'This is designed to create a full width page without a sidgets sidebar. In the website\'s content area, there is no styles.', 'tantyyellow' ) .
							'</p>' .
						'</li>' .

					'</ol>' .

				'</div>
			',
		)
	);

	/* ----- Help : What is "Customizer"? ------------------------------------------------- */
	$current_screen->add_help_tab(
		array(
			'id'      => 'tantyyellow_help_what_is_customizer',
			'title'   => esc_html__( 'What is "Customizer"?', 'tantyyellow' ),
			'content' =>

				'<p>' . esc_html__( '"Customizer" is one of WordPress\'s helpful features, which enables you to manage page styles, or options visually and intuitively without coding.', 'tantyyellow' ) . '</p>' .

				'<p>' . esc_html__( 'In order to use "Customizer" . . .', 'tantyyellow' ) . '</p>' .

				'<ol>' .

					'<li>' . esc_html__( 'Go to "Appearance" --> "Customize" --> "Customizer" screen from left "Admin Menu" . . .', 'tantyyellow' ) . '</li>' .

					'<li>' . esc_html__( 'Click the menu tab you want to set up . . .', 'tantyyellow' ) . '</li>' .

					'<li>' . esc_html__( 'Set up each item, such as inputting text/URL, defining image/video, choosing color/font, and so on . . .', 'tantyyellow' ) . '</li>' .

					'<li>' . esc_html__( 'And then, click "Publish" button at the top.', 'tantyyellow' ) . '</li>' .

					'<li style="text-indent:-1em; padding-left:1em;">' . esc_html__( 'Now, the change you have set up should be applied.', 'tantyyellow' ) . '</li>' .

				'</ol>
			',
		)
	);

	/* ----- Help : Customizer Settings --------------------------------------------------- */
	$current_screen->add_help_tab(
		array(
			'id'      => 'tantyyellow_help_customizer_settings',
			'title'   => esc_html__( 'Customizer Settings', 'tantyyellow' ),
			'content' =>

				'<div>' .

					'<ol>' .

						'<li>' .
							'<h4 style="margin-bottom: 0;"><span style="font-weight: 900;">' . esc_html__( 'Site Basic settings', 'tantyyellow' ) . '</span></h4>' .
							'<ol style="list-style-type: lower-latin">' .

								'<li>' .
									'<p>' . esc_html__( 'Pages Settings', 'tantyyellow' ) . '</p>' .
									'<ol style="list-style-type: lower-roman">' .
										'<li>' .
											'<p>' . esc_html__( 'Custom Posts Number per Page', 'tantyyellow' ) . '</p>' .
											'<ol style="list-style-type: lower-roman">' .
												'<li>' .
													'<p>' . esc_html__( 'Enable Custom Posts Number per Page', 'tantyyellow' ) . '</p>' .
												'</li>' .
												'<li>' .
													'<p>' .
														esc_html__( 'The Custom Posts Number for Each Page', 'tantyyellow' ) .
														' --> ' .
														esc_html__( 'Recent Posts Page', 'tantyyellow' ) . ' / ' .
														esc_html__( 'Search Results Page', 'tantyyellow' ) . ' / ' .
														esc_html__( 'Category Archive Page', 'tantyyellow' ) . ' / ' .
														esc_html__( 'Tag Archive Page', 'tantyyellow' ) . ' / ' .
														esc_html__( 'Author Archive Page', 'tantyyellow' ) . ' / ' .
														esc_html__( 'Day Archive Page', 'tantyyellow' ) . ' / ' .
														esc_html__( 'Month Archive Page', 'tantyyellow' ) . ' / ' .
														esc_html__( 'Year Archive Page', 'tantyyellow' ) .
													'</p>' .
												'</li>' .
											'</ol>' .
										'</li>' .
									'</ol>' .
								'</li>' .
								'<li>' .
									'<p>' . esc_html__( 'Posts Settings', 'tantyyellow' ) . '</p>' .
									'<ol style="list-style-type: lower-roman">' .
										'<li>' .
											'<p>' . esc_html__( 'All Posts Settings => Default Featured Image / Sticky Post\'s Badge', 'tantyyellow' ) . '</p>' .
										'</li>' .
										'<li>' .
											'<p>' . esc_html__( 'Each Post Settings => Post Meta Info', 'tantyyellow' ) . '</p>' .
										'</li>' .
										'<li>' .
											'<p>' . esc_html__( 'Each Post Settings(Archive Pages) => Each Post Meta Info / Enable Custom Excerpt Length', 'tantyyellow' ) . '</p>' .
										'</li>' .
									'</ol>' .
								'</li>' .
								'<li>' .
									'<p>' . esc_html__( 'Links Settings', 'tantyyellow' ) . '</p>' .
									'<ol style="list-style-type: none">' .
										'<li>' .
											'<p>' . esc_html__( 'Links Text-Underline / Links Text-Underline(Hovered)', 'tantyyellow' ) . '</p>' .
										'</li>' .
									'</ol>' .
								'</li>' .
								'<li>' .
									'<p>' . esc_html__( 'Auto-close Settings', 'tantyyellow' ) . '</p>' .
								'</li>' .
							'</ol>' .
						'</li>' .

						'<li>' .
							'<h4 style="margin-bottom: 0;"><span style="font-weight: 900;">' . esc_html__( 'Fonts settings', 'tantyyellow' ) . '</span></h4>' .
							'<ol style="list-style-type: lower-latin">' .
								'<li>' .
									'<p>' . esc_html__( 'Page Title Settings', 'tantyyellow' ) . '</p>' .
									'<ol style="list-style-type: none">' .
										'<li>' .
											'<p>' . esc_html__( 'Header Level / Sub Header Level / Paragraph Level', 'tantyyellow' ) . '</p>' .
										'</li>' .
									'</ol>' .
								'</li>' .
							'</ol>' .
						'</li>' .

						'<li>' .
							'<h4 style="margin-bottom: 0;"><span style="font-weight: 900;">' . esc_html__( 'Colors settings', 'tantyyellow' ) . '</span></h4>' .
							'<ol style="list-style-type: lower-latin">' .
								'<li>' .
									'<p>' . esc_html__( 'Page Title Settings', 'tantyyellow' ) . '</p>' .
									'<ol style="list-style-type: none">' .
										'<li>' .
											'<p>' .
												esc_html__( 'Background / Header Main Menu Background / Header Main Menu Background(Scrolled) / Header Main Menu Text / Header Main Menu Text(Scrolled) / Breadcrumb-List Gradient Background / Page Content Gradient Background / Side Widgets Gradient Background / Links Text / Links Text(Scrolled) / Each Post Border(Hovered) / Each Post Featured Image Translucent Background(Hovered) / Each Sticky Post Border(Hovered) / Each Sticky Post Featured Image Translucent Background(Hovered)', 'tantyyellow' ) .
											'</p>' .
										'</li>' .
									'</ol>' .
								'</li>' .
							'</ol>' .
						'</li>' .

					'</ol>' .

				'</div>
			',
		)
	);

	/* ----- Help : Edit Page Settings ---------------------------------------------------- */
	$current_screen->add_help_tab(
		array(
			'id'      => 'tantyyellow_help_edit_page_settings',
			'title'   => esc_html__( 'Edit Page Settings', 'tantyyellow' ),
			'content' =>

				'<div>' .

					'<h4 style="font-weight: 900;">' . esc_html__( 'Title(Subitle) Display Types Settings', 'tantyyellow' ) . '</h4>' .

					'<ol>' .

						'<p>' . esc_html__( 'This theme has the feature to be able to select a display type of a page title for the actual web page. You can set this in each static page and single post page.', 'tantyyellow' ) . '</p>' .

						'<li>' .
							'<h4 style="margin-bottom: 0;"><span style="font-weight: 900;">' . esc_html__( 'Default', 'tantyyellow' ) . '</span></h4>' .
							'<p style="margin-top: 0; margin-bottom: 0;">' .
								esc_html__( 'Display the same title as the edit page\'s title.', 'tantyyellow' ) .
							'</p>' .
						'</li>' .

						'<li>' .
							'<h4 style="margin-bottom: 0;"><span style="font-weight: 900;">' . esc_html__( 'Custom', 'tantyyellow' ) . '</span></h4>' .
							'<p style="margin-top: 0; margin-bottom: 0;">' .
								esc_html__( 'You can set the title you want to name, which can be different from the edit page\'s title.', 'tantyyellow' ) .
							'</p>' .
						'</li>' .

						'<li>' .
							'<h4 style="margin-bottom: 0;"><span style="font-weight: 900;">' . esc_html__( 'Disable', 'tantyyellow' ) . '</span></h4>' .
							'<p style="margin-top: 0; margin-bottom: 0;">' .
								esc_html__( 'Not display a title in the actual web page whether or not the edit page\'s title or the custom title is defined or not.', 'tantyyellow' ) .
							'</p>' .
						'</li>' .

					'</ol>' .

				'</div>' .

				'<div>' .

					'<h4 style="font-weight: 900;">' . esc_html__( 'Featured Image Display Types Settings', 'tantyyellow' ) . '</h4>' .

					'<ol>' .

						'<p>' . esc_html__( 'This theme has the feature to be able to select a display type of a page featured image for the actual web page. You can set this in each static page and single post page.', 'tantyyellow' ) . '</p>' .

						'<li>' .
							'<h4 style="margin-bottom: 0;"><span style="font-weight: 900;">' . esc_html__( 'Featured Image', 'tantyyellow' ) . '</span></h4>' .
							'<p style="margin-top: 0; margin-bottom: 0;">' .
								esc_html__( 'Display the featured image set in the right side panel in this editting page.', 'tantyyellow' ) .
							'</p>' .
						'</li>' .

						'<li>' .
							'<h4 style="margin-bottom: 0;"><span style="font-weight: 900;">' . esc_html__( 'Default Image', 'tantyyellow' ) . '</span></h4>' .
							'<p style="margin-top: 0; margin-bottom: 0;">' .
								esc_html__( 'Display the default featured image set in the "Site Basic" settings in "Dashboard --> Appearance --> Customize --> Site Basic Settings".', 'tantyyellow' ) .
							'</p>' .
						'</li>' .

						'<li>' .
							'<h4 style="margin-bottom: 0;"><span style="font-weight: 900;">' . esc_html__( 'Disable Image', 'tantyyellow' ) . '</span></h4>' .
							'<p style="margin-top: 0; margin-bottom: 0;">' .
								esc_html__( 'Not display a featured image in the actual web page whether or not a featured image on the right side menu or a default featured image in the "Site Basic Settings" is defined or not.', 'tantyyellow' ) .
							'</p>' .
						'</li>' .

					'</ol>' .

				'</div>
			',
		)
	);

}
add_action( 'admin_head', 'tantyyellow_add_contextual_helps' );
