<?php
/**
 * This file contains a set of functions in order to output Javascripts & CSSs.
 *
 * @package tantyyellow
 */

// ########################################################################################################################
// ##### Functions in order to output 'Javascript' before </body> & 'CSS' in <head> #######################################
// ########################################################################################################################

// ***** Scripts & CSSs *****************************************************************************************

/**
 * Register and Enqueue Styles.
 * Load stylesheets in <head>.
 */
function tantyyellow_register_styles() {

	$theme_ver = wp_get_theme()->get( 'Version' );

	/* Font Awesome CSS */
	wp_enqueue_style( 'style-fontawesome', get_theme_file_uri( '/src/vendors/fontawesome-free-5.2.0-web/css/all.css' ), array(), $theme_ver, 'all' );

	/* Bootstrap CSS */
	wp_enqueue_style( 'bootstrap', get_theme_file_uri( '/src/vendors/bootstrap-4.0.0/css/bootstrap.css' ), array(), $theme_ver, 'all' );

	/* Balloon.css (In order to display tooltips to elements) */
	wp_enqueue_style( 'style-balloon', get_theme_file_uri( '/src/vendors/css/balloon-css/balloon.css' ), array(), $theme_ver, 'all' );

	/* Google Fonts CSS */
	$google_fonts = array(
		// Lato ( font-family: 'Lato', sans-serif; ).
		'Lato:wght@400;700;900',
		// Slabo 27px ( font-family: 'Slabo 27px', serif; ).
		'Slabo+27px',
		// Oswald ( font-family: 'Oswald', sans-serif; ).
		'Oswald:wght@400;700',
		// Source Sans Pro ( font-family: 'Source Sans Pro', sans-serif; ).
		'Source+Sans+Pro:wght@400;700;900',
		// Montserrat ( font-family: 'Montserrat', sans-serif; ).
		'Montserrat:wght@400;700;900',
		// Raleway ( font-family: 'Raleway', sans-serif; ).
		'Raleway:wght@400;700;900',
		// PT Sans ( font-family: 'PT Sans', sans-serif; ).
		'PT+Sans:wght@400;700',
		// Lora ( font-family: 'Lora', serif; ).
		'Lora:wght@400;700',
		// Noto Sans JP ( font-family: 'Noto Sans JP', sans-serif; ).
		'Noto+Sans+JP:wght@400;700;900',
		// Noto Serif JP ( font-family: 'Noto Serif JP', serif; ).
		'Noto+Serif+JP:wght@400;700;900',
		// M PLUS 1p ( font-family: 'M PLUS 1p', sans-serif; ).
		'M+PLUS+1p:wght@400;700;900',
		// M PLUS Rounded 1c ( font-family: 'M PLUS Rounded 1c', sans-serif; ).
		'M+PLUS+Rounded+1c:wght@400;700;900',
		// Sawarabi Gothic ( font-family: 'Sawarabi Gothic', sans-serif; ).
		'Sawarabi+Gothic',
		// Sawarabi Mincho ( font-family: 'Sawarabi Mincho', sans-serif; ).
		'Sawarabi+Mincho',
	);

	$google_fonts_api_url = 'https://fonts.googleapis.com/css2?family=';
	foreach ( $google_fonts as $val ) {
		$google_fonts_api_url .= $val . '&';
	}
	$google_fonts_api_url .= 'display=swap';

	wp_enqueue_style( 'tantyyellow-googlefonts', $google_fonts_api_url, array(), $theme_ver, 'all' );

	/* Theme Style(style.css) */
	wp_enqueue_style( 'tantyyellow-style-main', get_stylesheet_uri(), array(), $theme_ver, 'all' );

}
add_action( 'wp_enqueue_scripts', 'tantyyellow_register_styles' );



/**
 * Register and Enqueue Scripts.
 * Load script right before </body>.
 */
function tantyyellow_register_scripts() {

	$theme_ver = wp_get_theme()->get( 'Version' );

	/* UAParser.js */
	wp_enqueue_script( 'script-ua-parser', get_theme_file_uri( '/src/vendors/js/UAParser.js/ua-parser.js' ), array( 'jquery' ), $theme_ver, false );

	/* UAParser.js Initializing */
	wp_enqueue_script( 'tantyyellow-script-ua-parser-init', get_theme_file_uri( '/src/assets/js/UAParser/user-agent-parser-init.js' ), array( 'jquery' ), $theme_ver, false );

	/* Bootstrap (Load 'popper.js' firstly,) */
	wp_enqueue_script( 'script-bootstrap-popper', get_theme_file_uri( '/src/vendors/bootstrap-4.0.0/js/popper.min.js' ), array( 'jquery' ), $theme_ver, false );

	/* Bootstrap (then, load 'bootstrap.js') */
	wp_enqueue_script( 'script-bootstrap', get_theme_file_uri( '/src/vendors/bootstrap-4.0.0/js/bootstrap.min.js' ), array( 'jquery' ), $theme_ver, false );

	/* Smooth Scroll */
	wp_enqueue_script( 'script-smooth-scroll', get_theme_file_uri( '/src/vendors/smooth-scroll/smooth-scroll.js' ), array( 'jquery' ), $theme_ver, false );

	/* Balloon.css */
	wp_enqueue_script( 'script-balloon', get_theme_file_uri( '/src/assets/js/balloon-css/balloonCSS-copy-to-clipboard-init.js' ), array( 'jquery' ), $theme_ver, false );

	/* Load theme script ( main-module.js ) */
	wp_enqueue_script( 'tantyyellow-script-main-module', get_theme_file_uri( '/src/assets/js/main-module.js' ), array( 'jquery' ), $theme_ver, false );

	/* Load theme script ( main.js ) */
	wp_enqueue_script( 'tantyyellow-script-main', get_theme_file_uri( '/src/assets/js/main.js' ), array( 'jquery' ), $theme_ver, false );

	/* Load '/wp-includes/js/comment-reply.js' in order to enable threaded (nested) comments */
	if ( ( is_single() ) && ( comments_open() ) && ( get_option( 'thread_comments' ) ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

}
add_action( 'wp_enqueue_scripts', 'tantyyellow_register_scripts' );



// ***** Customizer JavaScript APIs *****************************************************************************

/**
 * Register and Enqueue styles for Customizer JavaScript API "Customizer Control".
 */
function tantyyellow_register_customize_control() {

	$theme_ver = wp_get_theme()->get( 'Version' );

	wp_enqueue_script( 'tantyyellow-script-customizer-control', get_theme_file_uri( '/src/admin/customize_admin_panel/customizer_javascript_apis/tantyyellow_customizer_control.js' ), array( 'customize-controls', 'jquery' ), $theme_ver, true );
}
add_action( 'customize_controls_enqueue_scripts', 'tantyyellow_register_customize_control' );



// ***** Custom scripts & CSSs **********************************************************************************

/**
 * Register and Enqueue styles for "Gutenberg Editor".
 */
function tantyyellow_add_gutenberg_editor_styles() {

	$theme_ver = wp_get_theme()->get( 'Version' );

	wp_enqueue_style( 'tantyyellow-style-gutenberg-editor', get_theme_file_uri( '/src/admin/gutenberg_editor_stylesheet/gutenberg-editor.css' ), array(), $theme_ver, 'all' );
}
add_action( 'enqueue_block_editor_assets', 'tantyyellow_add_gutenberg_editor_styles' );



/**
 * Register and Enqueue styles for "TinyMCE Editor".
 */
function tantyyellow_add_tiny_mce_editor_styles() {
	add_editor_style( '/src/admin/TinyMCE_editor_stylesheet/tiny-mce-editor.css' );
}
add_action( 'admin_init', 'tantyyellow_add_tiny_mce_editor_styles' );



/**
 * Register and Enqueue Admin Panel Theme Customizer Styles.
 * In order to load custom CSS in <head>.
 *
 * @link https://aristath.github.io/blog/modifying-wordpress-customizer
 * @link Line-163 at customize.php
 */
function tantyyellow_load_admin_panel_theme_customizer_screen_css_in_head() {

	$theme_ver = wp_get_theme()->get( 'Version' );

	/* Style admin panel theme customizer screen */
	wp_enqueue_style( 'tantyyellow-style-admin-panel-theme-customizer-screen', get_theme_file_uri( '/src/admin/customize_admin_panel/theme_customizer_screen/tantyyellow_admin_panel_theme_customizer_screen.css' ), array(), $theme_ver, 'all' );

}
add_action( 'customize_controls_print_styles', 'tantyyellow_load_admin_panel_theme_customizer_screen_css_in_head' );



/**
 * Register and Enqueue Admin Panel Theme Customizer Scripts.
 * In order to load custom Javascript before </body>.
 */
function tantyyellow_load_admin_panel_theme_customizer_screen_scripts_in_head() {

	$theme_ver = wp_get_theme()->get( 'Version' );

	wp_enqueue_script( 'tantyyellow-script-admin-panel-theme-customizer-screen', get_theme_file_uri( '/src/admin/customize_admin_panel/theme_customizer_screen/tantyyellow_admin_panel_theme_customizer_screen.js' ), array(), $theme_ver, false );

}
add_action( 'customize_controls_print_scripts', 'tantyyellow_load_admin_panel_theme_customizer_screen_scripts_in_head' );



/**
 * Register and Enqueue Admin Panel Theme Customizer Scripts.
 * In order to load custom Javascript before </body>.
 *
 * - The data as an array will be passed to "tantyyellow_admin_panel.js" where the data can be used as a variable storing the array.
 */
function tantyyellow_load_admin_panel_scripts_in_head() {

	$theme_ver = wp_get_theme()->get( 'Version' );

	wp_enqueue_script( 'tantyyellow-script-admin-panel', get_theme_file_uri( '/src/admin/customize_admin_panel/tantyyellow_admin_panel.js' ), array(), $theme_ver, false );

	/* Pass the data defined in PHP to Javascript. */
	wp_localize_script(
		/* Handle name. */
		'tantyyellow-script-admin-panel',
		/* This string is used as a variable in Javascript storing the following array. */
		'tantyyellow_arr_passing_php_data_to_admin_panel_js',
		/* The array will be stored as data of above variable. */
		array(
			'admin' => array(
				'settings' => array(
					'discussion' => array(

						/**
						 * This is for the setting "Comments should be displayed with the newer comments at the top of each page"
						 * in order to change "older ==> newer" and "newer ==> older" in "Admin Panel ==> Settings Tab ==> Discussion".
						 */
						'each_page_comment_order' => array(
							'older' => esc_html__( 'older', 'tantyyellow' ),
							'newer' => esc_html__( 'newer', 'tantyyellow' ),
						),
					),
				),
			),
		)
	);

}
add_action( 'admin_enqueue_scripts', 'tantyyellow_load_admin_panel_scripts_in_head' );



// ***** Fixing <script> & <link>(stylesheet) Attributes ********************************************************

if ( ! is_admin() ) {
	/**
	 * Fix <script> tag attributes.
	 * - Add "defer" attribute to all <script>s except for "jQuery".
	 * - The function in order not to output 'type=text/javascript' in <script> and 'type=text/css' in <link> is defined
	 *   by "add_theme_support( 'html5' )" in the "setups.php".
	 *
	 * @link https://www.firstplanet.ca/remove-type-attribute/
	 * @link https://on-ze.com/archives/2513
	 * @link https://wordpress.stackexchange.com/questions/287830/remove-type-attribute-from-script-and-style-tags-added-by-wordpress
	 * @link https://stackoverflow.com/questions/49528153/remove-type-attribute-from-script-tags-in-wordpress/53380692#53380692
	 *
	 * @param string $tag_script The <script> tag prior to fixing.
	 * @param string $handle     The name of a handle name assigned when registering script.
	 *
	 * @return string The fixed <script> tag.
	 */
	function tantyyellow_fix_script_tag_attrs( $tag_script, $handle ) {

		if ( 'jquery' !== $handle ) {

			// If the <script> is for jQuery..., do nothing, if not..., continue.
			if (
				! (
					strpos( $tag_script, 'jquery.js' ) ||
					strpos( $tag_script, 'jquery.min.js' ) ||
					strpos( $tag_script, 'jquery-migrate' )
				)
			) {

				// If the <script> is registered by the theme...
				if (
					'tantyyellow-script-ua-parser' === $handle ||
					'tantyyellow-script-ua-parser-init' === $handle ||
					'tantyyellow-script-bootstrap-popper' === $handle ||
					'tantyyellow-script-bootstrap' === $handle ||
					'tantyyellow-script-slick' === $handle ||
					'tantyyellow-script-slick-init' === $handle ||
					'tantyyellow-script-smooth-scroll' === $handle ||
					'tantyyellow-script-infinite-scroll' === $handle ||
					'tantyyellow-script-infinite-scroll-init' === $handle ||
					'tantyyellow-script-balloon' === $handle ||
					'tantyyellow-script-youtube-api' === $handle ||
					'tantyyellow-script-video-control' === $handle ||
					'tantyyellow-script-main' === $handle ||
					'tantyyellow-script-comment-reply' === $handle
				) {

					$tag_script = str_replace( ' src', ' defer src', $tag_script );
				}
			}

			if ( 'tantyyellow-script-main' === $handle || 'tantyyellow-script-main-module' === $handle ) {
				$tag_script = str_replace( ' src', ' type="module" src', $tag_script );
			}
		}
		return $tag_script;

	}
	add_filter( 'script_loader_tag', 'tantyyellow_fix_script_tag_attrs', 10, 2 );
} // End of "if ( ! is_admin() )".
