<?php
/**
 * "theme-customizer-colors.php"
 *
 * @package tantyyellow
 */

// ########################################################################################################################
// ##### Functions for 'Colors' to customize theme ########################################################################
// ########################################################################################################################

/**
 * Define function for action hook "customize_register".
 * - Register theme customizer for "Colors" section.
 *
 * @param WP_Customize_Manager $wp_customize Customizer object, which is an instance of the WP_Customize_Manager class.
 */
function tantyyellow_theme_customizer_register_colors( $wp_customize ) {

	// '$wp_customize->add_section...' is not necessary because 'Colors' section exists as default ( priority => 40 ).
	// However, in order to change the title, re-define it.
	$wp_customize->add_section(
		'colors',
		array(
			'title'    => esc_html__( 'Colors Settings', 'tantyyellow' ),
			'priority' => 40,
		)
	);

		/* ===== Header main menu 'default' background color ======================================== */
		$wp_customize->add_setting(
			'custom_colors_header_main_menu_bg_default_setting',
			array(
				'default'           => '#ffffff',
				'sanitize_callback' => 'sanitize_hex_color',
			)
		);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,
					'custom_colors_header_main_menu_bg_default_control',
					array(
						'label'    => esc_html__( 'Header Main Menu Background-Color', 'tantyyellow' ),
						'section'  => 'colors',
						'settings' => 'custom_colors_header_main_menu_bg_default_setting',
					)
				)
			);

		/* ===== Header main menu 'scrolled' background color ======================================= */
		$wp_customize->add_setting(
			'custom_colors_header_main_menu_bg_scrolled_setting',
			array(
				'default'           => '#393939',
				'sanitize_callback' => 'sanitize_hex_color',
			)
		);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,
					'custom_colors_header_main_menu_bg_scrolled_control',
					array(
						'label'    => esc_html__( 'Header Main Menu Background-Color(Scrolled)', 'tantyyellow' ),
						'section'  => 'colors',
						'settings' => 'custom_colors_header_main_menu_bg_scrolled_setting',
					)
				)
			);

		/* ===== Header main menu text color ======================================================== */
		$wp_customize->add_setting(
			'custom_colors_header_main_menu_text_setting',
			array(
				'default'           => '#7b7b7b',
				'sanitize_callback' => 'sanitize_hex_color',
			)
		);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,
					'custom_colors_header_main_menu_text_control',
					array(
						'label'    => esc_html__( 'Header Main Menu Text-Color', 'tantyyellow' ),
						'section'  => 'colors',
						'settings' => 'custom_colors_header_main_menu_text_setting',
					)
				)
			);

		/* ===== Header main menu 'scrolled' text color ============================================= */
		$wp_customize->add_setting(
			'custom_colors_header_main_menu_scrolled_text_setting',
			array(
				'default'           => '#7b7b7b',
				'sanitize_callback' => 'sanitize_hex_color',
			)
		);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,
					'custom_colors_header_main_menu_scrolled_text_control',
					array(
						'label'    => esc_html__( 'Header Main Menu Text-Color(Scrolled)', 'tantyyellow' ),
						'section'  => 'colors',
						'settings' => 'custom_colors_header_main_menu_scrolled_text_setting',
					)
				)
			);

		/* ===== Side menu background color ========================================================= */
		$wp_customize->add_setting(
			'custom_colors_side_menu_bg_setting',
			array(
				'default'           => '#2c2c2c',
				'sanitize_callback' => 'sanitize_hex_color',
			)
		);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,
					'custom_colors_side_menu_bg_control',
					array(
						'label'    => esc_html__( 'Side Main Menu Background-Color', 'tantyyellow' ),
						'section'  => 'colors',
						'settings' => 'custom_colors_side_menu_bg_setting',
					)
				)
			);

		/* ===== Breadcrumb bar background gradient color 01 ======================================== */
		$wp_customize->add_setting(
			'custom_colors_breadcrumb_bar_bg_gradient_01_setting',
			array(
				'default'           => '#feffe1',
				'sanitize_callback' => 'sanitize_hex_color',
			)
		);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,
					'custom_colors_breadcrumb_bar_bg_gradient_01_control',
					array(
						'label'    => esc_html__( 'Breadcrumb-List Gradient Background-Color 01', 'tantyyellow' ),
						'section'  => 'colors',
						'settings' => 'custom_colors_breadcrumb_bar_bg_gradient_01_setting',
					)
				)
			);

		/* ===== Breadcrumb bar background gradient color 02 ======================================== */
		$wp_customize->add_setting(
			'custom_colors_breadcrumb_bar_bg_gradient_02_setting',
			array(
				'default'           => '#def038',
				'sanitize_callback' => 'sanitize_hex_color',
			)
		);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,
					'custom_colors_breadcrumb_bar_bg_gradient_02_control',
					array(
						'label'    => esc_html__( 'Breadcrumb-List Gradient Background-Color 02', 'tantyyellow' ),
						'section'  => 'colors',
						'settings' => 'custom_colors_breadcrumb_bar_bg_gradient_02_setting',
					)
				)
			);

		/* ===== Contents main background gradient color 01 ========================================= */
		$wp_customize->add_setting(
			'custom_colors_contents_main_bg_gradient_01_setting',
			array(
				'default'           => '#feffe1',
				'sanitize_callback' => 'sanitize_hex_color',
			)
		);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,
					'custom_colors_contents_main_bg_gradient_01_control',
					array(
						'label'    => esc_html__( 'Page Content Gradient Background-Color 01', 'tantyyellow' ),
						'section'  => 'colors',
						'settings' => 'custom_colors_contents_main_bg_gradient_01_setting',
					)
				)
			);

		/* ===== Contents main background gradient color 02 ========================================= */
		$wp_customize->add_setting(
			'custom_colors_contents_main_bg_gradient_02_setting',
			array(
				'default'           => '#def038',
				'sanitize_callback' => 'sanitize_hex_color',
			)
		);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,
					'custom_colors_contents_main_bg_gradient_02_control',
					array(
						'label'    => esc_html__( 'Page Content Gradient Background-Color 02', 'tantyyellow' ),
						'section'  => 'colors',
						'settings' => 'custom_colors_contents_main_bg_gradient_02_setting',
					)
				)
			);

		/* ===== Sidebar widgets background gradient color 01 ======================================= */
		$wp_customize->add_setting(
			'custom_colors_sidebar_widgets_bg_gradient_01_setting',
			array(
				'default'           => '#feffe1',
				'sanitize_callback' => 'sanitize_hex_color',
			)
		);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,
					'custom_colors_sidebar_widgets_bg_gradient_01_control',
					array(
						'label'    => esc_html__( 'Side Widgets Gradient Background-Color 01', 'tantyyellow' ),
						'section'  => 'colors',
						'settings' => 'custom_colors_sidebar_widgets_bg_gradient_01_setting',
					)
				)
			);

		/* ===== Sidebar widgets background gradient color 02 ======================================= */
		$wp_customize->add_setting(
			'custom_colors_sidebar_widgets_bg_gradient_02_setting',
			array(
				'default'           => '#def038',
				'sanitize_callback' => 'sanitize_hex_color',
			)
		);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,
					'custom_colors_sidebar_widgets_bg_gradient_02_control',
					array(
						'label'    => esc_html__( 'Side Widgets Gradient Background-Color 02', 'tantyyellow' ),
						'section'  => 'colors',
						'settings' => 'custom_colors_sidebar_widgets_bg_gradient_02_setting',
					)
				)
			);

		/* ===== All pages Link color =============================================================== */
		$wp_customize->add_setting(
			'custom_colors_all_links_text_setting',
			array(
				'default'           => '#5bc52e',
				'sanitize_callback' => 'sanitize_hex_color',
			)
		);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,
					'custom_colors_all_links_text_control',
					array(
						'label'    => esc_html__( 'Links Text-Color', 'tantyyellow' ),
						'section'  => 'colors',
						'settings' => 'custom_colors_all_links_text_setting',
					)
				)
			);

		/* ===== All pages Link 'hovered' color ===================================================== */
		$wp_customize->add_setting(
			'custom_colors_all_links_hovered_text_setting',
			array(
				'default'           => '#2b9000',
				'sanitize_callback' => 'sanitize_hex_color',
			)
		);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,
					'custom_colors_all_links_hovered_text_control',
					array(
						'label'    => esc_html__( 'Links Text-Color(Hovered)', 'tantyyellow' ),
						'section'  => 'colors',
						'settings' => 'custom_colors_all_links_hovered_text_setting',
					)
				)
			);

		/* ===== Each post border 'hovered' color =================================================== */
		$wp_customize->add_setting(
			'custom_colors_each_post_border_hovered_setting',
			array(
				'default'           => '#61725a',
				'sanitize_callback' => 'sanitize_hex_color',
			)
		);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,
					'custom_colors_each_post_border_hovered_control',
					array(
						'label'    => esc_html__( 'Each Post Border-Color(Hovered)', 'tantyyellow' ),
						'section'  => 'colors',
						'settings' => 'custom_colors_each_post_border_hovered_setting',
					)
				)
			);

		/* ===== Each post image background 'hovered' color ========================================= */
		$wp_customize->add_setting(
			'custom_colors_each_post_image_bg_hovered_setting',
			array(
				'default'           => '#71eb71',
				'sanitize_callback' => 'sanitize_hex_color',
			)
		);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,
					'custom_colors_each_post_image_bg_hovered_control',
					array(
						'label'    => esc_html__( 'Each Post Feature Image Translucent Background-Color(Hovered)', 'tantyyellow' ),
						'section'  => 'colors',
						'settings' => 'custom_colors_each_post_image_bg_hovered_setting',
					)
				)
			);

		/* ===== Each sticky post border 'hovered' color ============================================ */
		$wp_customize->add_setting(
			'custom_colors_each_sticky_post_border_hovered_setting',
			array(
				'default'           => '#ee494e',
				'sanitize_callback' => 'sanitize_hex_color',
			)
		);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,
					'custom_colors_each_sticky_post_border_hovered_control',
					array(
						'label'    => esc_html__( 'Each Sticky Post Border-Color(Hovered)', 'tantyyellow' ),
						'section'  => 'colors',
						'settings' => 'custom_colors_each_sticky_post_border_hovered_setting',
					)
				)
			);

		/* ===== Each sticky post image background 'hovered' color ================================== */
		$wp_customize->add_setting(
			'custom_colors_each_sticky_post_image_bg_hovered_setting',
			array(
				'default'           => '#ff9f9f',
				'sanitize_callback' => 'sanitize_hex_color',
			)
		);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,
					'custom_colors_each_sticky_post_image_bg_hovered_control',
					array(
						'label'    => esc_html__( 'Each Sticky Post Feature Image Translucent Background-Color(Hovered)', 'tantyyellow' ),
						'section'  => 'colors',
						'settings' => 'custom_colors_each_sticky_post_image_bg_hovered_setting',
					)
				)
			);

}
add_action( 'customize_register', 'tantyyellow_theme_customizer_register_colors' );



/**
 * Define function for action hook "wp_head".
 * 01. Retrieve the value of colors put in the "Colors" customizer panel and set its default value.
 * 02. Apply colors styles to DOM content.
 */
function tantyyellow_theme_customizer_css_colors() {

	/* ===== Header main menu 'default' background color ======================================== */
	$custom_colors_header_main_menu_bg_default = get_theme_mod(
		'custom_colors_header_main_menu_bg_default_setting',
		'#ffffff'
	);

	/* ===== Header main menu 'scrolled' background color ======================================= */
	$custom_colors_header_main_menu_bg_scrolled = get_theme_mod(
		'custom_colors_header_main_menu_bg_scrolled_setting',
		'#393939'
	);

	/* ===== Header main menu 'default' text color ============================================== */
	$custom_colors_header_main_menu_text = get_theme_mod(
		'custom_colors_header_main_menu_text_setting',
		'#7b7b7b'
	);

	/* ===== Header main menu 'scrolled' text color ============================================= */
	$custom_colors_header_main_menu_scrolled_text = get_theme_mod(
		'custom_colors_header_main_menu_scrolled_text_setting',
		'#7b7b7b'
	);

	/* ===== Side menu background color ========================================================= */
	$custom_colors_side_menu_bg = get_theme_mod(
		'custom_colors_side_menu_bg_setting',
		'#2c2c2c'
	);

	/* ===== Breadcrumb bar background gradient color 01 ======================================== */
	$custom_colors_breadcrumb_bar_bg_gradient_01 = get_theme_mod(
		'custom_colors_breadcrumb_bar_bg_gradient_01_setting',
		'#feffe1'
	);

	/* ===== Breadcrumb bar background gradient color 02 ======================================== */
	$custom_colors_breadcrumb_bar_bg_gradient_02 = get_theme_mod(
		'custom_colors_breadcrumb_bar_bg_gradient_02_setting',
		'#def038'
	);

	/* ===== Contents main background gradient color 01 ========================================= */
	$custom_colors_contents_main_bg_gradient_01 = get_theme_mod(
		'custom_colors_contents_main_bg_gradient_01_setting',
		'#feffe1'
	);

	/* ===== Contents main background gradient color 02 ========================================= */
	$custom_colors_contents_main_bg_gradient_02 = get_theme_mod(
		'custom_colors_contents_main_bg_gradient_02_setting',
		'#def038'
	);

	/* ===== Sidebar widgets background gradient color 01 ======================================= */
	$custom_colors_sidebar_widgets_bg_gradient_01 = get_theme_mod(
		'custom_colors_sidebar_widgets_bg_gradient_01_setting',
		'#feffe1'
	);

	/* ===== Sidebar widgets background gradient color 02 ======================================= */
	$custom_colors_sidebar_widgets_bg_gradient_02 = get_theme_mod(
		'custom_colors_sidebar_widgets_bg_gradient_02_setting',
		'#def038'
	);

	/* ===== All pages Link color =============================================================== */
	$custom_colors_all_links_text = get_theme_mod(
		'custom_colors_all_links_text_setting',
		'#5bc52e'
	);

	/* ===== All pages Link 'hovered' color ===================================================== */
	$custom_colors_all_links_hovered_text = get_theme_mod(
		'custom_colors_all_links_hovered_text_setting',
		'#2b9000'
	);

	/* ===== Each post border 'hovered' color =================================================== */
	$custom_colors_each_post_border_hovered = get_theme_mod(
		'custom_colors_each_post_border_hovered_setting',
		'#61725a'
	);

	/* ===== Each post image background 'hovered' color ========================================= */
	$custom_colors_each_post_image_bg_hovered = get_theme_mod(
		'custom_colors_each_post_image_bg_hovered_setting',
		'#71eb71'
	);

	/* ===== Each sticky post border 'hovered' color =================================================== */
	$custom_colors_each_sticky_post_border_hovered = get_theme_mod(
		'custom_colors_each_sticky_post_border_hovered_setting',
		'#ee494e'
	);

	/* ===== Each sticky post image background 'hovered' color ========================================= */
	$custom_colors_each_sticky_post_image_bg_hovered = get_theme_mod(
		'custom_colors_each_sticky_post_image_bg_hovered_setting',
		'#ff9f9f'
	);

	?>



	<style type="text/css">

		/* ===== Header main menu 'default' background color ======================================== */
		div#header-nav.page-wrapper {
			background: <?php echo esc_attr( $custom_colors_header_main_menu_bg_default ); ?>;
		}

		/* ===== Header main menu 'scrolled' background color ======================================= */
		div#header-nav.page-wrapper.scrolled {
			background: <?php echo esc_attr( $custom_colors_header_main_menu_bg_scrolled ); ?>;
		}

		/* ===== Header main menu 'default' text color ============================================== */
		div#header-nav.page-wrapper nav#header-nav-sidebar-wrapper div.sidebar-content div.sidebar-menu ul#header-nav-list li.main-menu-item a.main-menu-link:after,
		div#header-nav.page-wrapper nav#header-nav-sidebar-wrapper div.sidebar-content div.sidebar-menu ul#header-nav-list li.main-menu-item a.main-menu-link span {
			color: <?php echo esc_attr( $custom_colors_header_main_menu_text ); ?>;
		}

		/* ===== Header main menu 'scrolled' text color ============================================= */
		div#header-nav.page-wrapper.scrolled nav#header-nav-sidebar-wrapper div.sidebar-content div.sidebar-menu ul#header-nav-list li.main-menu-item a.main-menu-link:after,
		div#header-nav.page-wrapper.scrolled nav#header-nav-sidebar-wrapper div.sidebar-content div.sidebar-menu ul#header-nav-list li.main-menu-item a.main-menu-link span {
			color: <?php echo esc_attr( $custom_colors_header_main_menu_scrolled_text ); ?>;
		}

		/* ===== Side menu background color ========================================================= */
		@media screen and (max-width: 960px) { /* $max-width-tablet-l: 960px */
			div#header-nav.page-wrapper nav#header-nav-sidebar-wrapper {
				background: <?php echo esc_attr( $custom_colors_side_menu_bg ); ?>f5;
			}
		}

		/* ===== Breadcrumb bar background gradient color =========================================== */
		nav#breadcrumb.scrolled {
			background: linear-gradient(-90deg, <?php echo esc_attr( $custom_colors_breadcrumb_bar_bg_gradient_01 ); ?>, <?php echo esc_attr( $custom_colors_breadcrumb_bar_bg_gradient_02 ); ?>);
		}

		/* ===== Contents main background gradient color =========================================== */
		div.contents div#contents-main {
			background: linear-gradient(-90deg, <?php echo esc_attr( $custom_colors_contents_main_bg_gradient_01 ); ?>, <?php echo esc_attr( $custom_colors_contents_main_bg_gradient_02 ); ?>);
		}

		/* ===== Sidebar widgets background gradient color ========================================== */
		div.contents-sidebar div.contents-sidebar-wrapper div.contents-sidebar-inner {
			background: linear-gradient(90deg, <?php echo esc_attr( $custom_colors_sidebar_widgets_bg_gradient_01 ); ?>, <?php echo esc_attr( $custom_colors_sidebar_widgets_bg_gradient_02 ); ?>);
		}

		/* ===== All pages Link color =============================================================== */
		a {
			color: <?php echo esc_attr( $custom_colors_all_links_text ); ?>;
		}

		/* ===== All pages Link 'hovered' color ===================================================== */
		a:hover {
			color: <?php echo esc_attr( $custom_colors_all_links_hovered_text ); ?>;
		}

		/* ===== Each post border 'hovered' color =================================================== */
		.posts-loop main.row div.posts-loop-wrapper:hover,
		.posts-loop main.row div.posts-loop-wrapper:focus-within {
			border: 18px solid <?php echo esc_attr( $custom_colors_each_post_border_hovered ); ?>bf;
			outline: unset;
		}

		/* ===== Each post image background 'hovered' color ========================================= */
		.posts-loop.loop-sub#posts-loop-sub-is-single-page main.row div.posts-loop-wrapper article.post-loop header.each-post-header div.each-post-header-inner div.each-post-info,
		.posts-loop main.row div.posts-loop-wrapper article.post-loop header.each-post-header div.each-post-header-inner div.each-post-info {
			background: <?php echo esc_attr( $custom_colors_each_post_image_bg_hovered ); ?>bf;
		}

		/* ===== Each sticky post border 'hovered' color =================================================== */
		.posts-loop main.row div.posts-loop-wrapper.sticky-post-wrapper:hover,
		.posts-loop main.row div.posts-loop-wrapper.sticky-post-wrapper:focus-within {
			border: 18px solid <?php echo esc_attr( $custom_colors_each_sticky_post_border_hovered ); ?>bf;
			outline: unset;
		}

		/* ===== Each sticky post image background 'hovered' color ========================================= */
		.posts-loop.loop-sub#posts-loop-sub-is-single-page main.row div.posts-loop-wrapper.sticky-post-wrapper article.post-loop header.each-post-header div.each-post-header-inner div.each-post-info,
		.posts-loop main.row div.posts-loop-wrapper.sticky-post-wrapper article.post-loop header.each-post-header div.each-post-header-inner div.each-post-info {
			background: <?php echo esc_attr( $custom_colors_each_sticky_post_image_bg_hovered ); ?>bf;
		}

	</style>

	<?php
} /* End of 'function tantyyellow_theme_customizer_css_colors()' */

add_action( 'wp_head', 'tantyyellow_theme_customizer_css_colors' );
