<?php
/**
 * "theme-customizer-fonts.php"
 *
 * @package tantyyellow
 */

// ########################################################################################################################
// ##### Functions for 'Fonts' to customize theme #########################################################################
// ########################################################################################################################

/**
 * Define function for action hook "customize_register".
 * - Register theme customizer for "Fonts" section.
 *
 * @param WP_Customize_Manager $wp_customize Customizer object, which is an instance of the WP_Customize_Manager class.
 */
function tantyyellow_theme_customizer_register_fonts( $wp_customize ) {

	$wp_customize->add_section(
		'fonts_section',
		array(
			'title'       => esc_html__( 'Fonts Settings', 'tantyyellow' ),
			'priority'    => 32,
			'description' => esc_html__( 'Set font-family.', 'tantyyellow' ),
		)
	);

		/* ===== Font-family of 'Heading' level ===================================================== */
		$wp_customize->add_setting(
			'general_font_family_heading_setting',
			array(
				'default'           => 'corporate_logo_bold',
				'type'              => 'theme_mod',
				'transport'         => 'postMessage',
				'sanitize_callback' => 'tantyyellow_sanitize_select_radio_callback',
			)
		);

			$wp_customize->add_control(
				'general_font_family_heading_control',
				array(
					'label'    => esc_html__( 'Header Level', 'tantyyellow' ),
					'section'  => 'fonts_section',
					'settings' => 'general_font_family_heading_setting',
					'type'     => 'select',
					'choices'  => array(

						/* DEFAULT */
						'default_font'          => esc_html__( '*** DEFAULT FONT ***', 'tantyyellow' ),
						'heading_default'       => esc_html__( 'Corporate Logo Bold', 'tantyyellow' ),
						'blank_default'         => '',
						'english_fonts'         => esc_html__( '*** ENGLISH FONTS ***', 'tantyyellow' ),
						'lato'                  => esc_html__( 'Lato', 'tantyyellow' ),
						'slabo_27px'            => esc_html__( 'Slabo 27px', 'tantyyellow' ),
						'oswald'                => esc_html__( 'Oswald', 'tantyyellow' ),
						'source_sans_pro'       => esc_html__( 'Source Sans Pro', 'tantyyellow' ),
						'montserrat'            => esc_html__( 'Montserrat', 'tantyyellow' ),
						'raleway'               => esc_html__( 'Raleway', 'tantyyellow' ),
						'pt_sans'               => esc_html__( 'PT Sans', 'tantyyellow' ),
						'lora'                  => esc_html__( 'Lora', 'tantyyellow' ),
						'blank_en'              => '',
						'japanese_fonts'        => esc_html__( '*** JAPANESE FONTS ***', 'tantyyellow' ),
						'corporate_logo_medium' => esc_html__( 'Corporate Logo Medium', 'tantyyellow' ),
						'genJyuu_gothic'        => esc_html__( 'GenJyuu Gothic', 'tantyyellow' ),
						'noto_sans_jp'          => esc_html__( 'Noto Sans JP', 'tantyyellow' ),
						'noto_serif_jp'         => esc_html__( 'Noto Serif JP', 'tantyyellow' ),
						'm_plus_1p'             => esc_html__( 'M PLUS 1p', 'tantyyellow' ),
						'm_plus_rounded_1c'     => esc_html__( 'M PLUS Rounded 1c', 'tantyyellow' ),
						'sawarabi_gothic'       => esc_html__( 'Sawarabi Gothic', 'tantyyellow' ),
						'sawarabi_mincho'       => esc_html__( 'Sawarabi Mincho', 'tantyyellow' ),
						'blank_ja'              => '',
					),
				)
			);

		/* ===== Font-family of 'Sub Heading' level ================================================= */
		$wp_customize->add_setting(
			'general_font_family_subheading_setting',
			array(
				'default'           => 'corporate_logo_medium',
				'type'              => 'theme_mod',
				'transport'         => 'postMessage',
				'sanitize_callback' => 'tantyyellow_sanitize_select_radio_callback',
			)
		);

			$wp_customize->add_control(
				'general_font_family_subheading_control',
				array(
					'label'    => esc_html__( 'Sub Header Level', 'tantyyellow' ),
					'section'  => 'fonts_section',
					'settings' => 'general_font_family_subheading_setting',
					'type'     => 'select',
					'choices'  => array(

						/* DEFAULT */
						'default_font'        => esc_html__( '*** DEFAULT FONT ***', 'tantyyellow' ),
						'subheading_default'  => esc_html__( 'Corporate Logo Medium', 'tantyyellow' ),
						'blank_default'       => '',
						'english_fonts'       => esc_html__( '*** ENGLISH FONTS ***', 'tantyyellow' ),
						'lato'                => esc_html__( 'Lato', 'tantyyellow' ),
						'slabo_27px'          => esc_html__( 'Slabo 27px', 'tantyyellow' ),
						'oswald'              => esc_html__( 'Oswald', 'tantyyellow' ),
						'source_sans_pro'     => esc_html__( 'Source Sans Pro', 'tantyyellow' ),
						'montserrat'          => esc_html__( 'Montserrat', 'tantyyellow' ),
						'raleway'             => esc_html__( 'Raleway', 'tantyyellow' ),
						'pt_sans'             => esc_html__( 'PT Sans', 'tantyyellow' ),
						'lora'                => esc_html__( 'Lora', 'tantyyellow' ),
						'blank_en'            => '',
						'japanese_fonts'      => esc_html__( '*** JAPANESE FONTS ***', 'tantyyellow' ),
						'corporate_logo_bold' => esc_html__( 'Corporate Logo Bold', 'tantyyellow' ),
						'genJyuu_gothic'      => esc_html__( 'GenJyuu Gothic', 'tantyyellow' ),
						'noto_sans_jp'        => esc_html__( 'Noto Sans JP', 'tantyyellow' ),
						'noto_serif_jp'       => esc_html__( 'Noto Serif JP', 'tantyyellow' ),
						'm_plus_1p'           => esc_html__( 'M PLUS 1p', 'tantyyellow' ),
						'm_plus_rounded_1c'   => esc_html__( 'M PLUS Rounded 1c', 'tantyyellow' ),
						'sawarabi_gothic'     => esc_html__( 'Sawarabi Gothic', 'tantyyellow' ),
						'sawarabi_mincho'     => esc_html__( 'Sawarabi Mincho', 'tantyyellow' ),
						'blank_ja'            => '',
					),
				)
			);

		/* ===== Font-family of 'Paragraph' level =================================================== */
		$wp_customize->add_setting(
			'general_font_family_paragraph_setting',
			array(
				'default'           => 'genJyuu_gothic',
				'type'              => 'theme_mod',
				'transport'         => 'postMessage',
				'sanitize_callback' => 'tantyyellow_sanitize_select_radio_callback',
			)
		);

			$wp_customize->add_control(
				'general_font_family_paragraph_control',
				array(
					'label'    => esc_html__( 'Paragraph Level', 'tantyyellow' ),
					'section'  => 'fonts_section',
					'settings' => 'general_font_family_paragraph_setting',
					'type'     => 'select',
					'choices'  => array(

						/* DEFAULT */
						'default_font'          => esc_html__( '*** DEFAULT FONT ***', 'tantyyellow' ),
						'paragraph_default'     => esc_html__( 'GenJyuu Gothic', 'tantyyellow' ),
						'blank_default'         => '',
						'english_fonts'         => esc_html__( '*** ENGLISH FONTS ***', 'tantyyellow' ),
						'lato'                  => esc_html__( 'Lato', 'tantyyellow' ),
						'slabo_27px'            => esc_html__( 'Slabo 27px', 'tantyyellow' ),
						'oswald'                => esc_html__( 'Oswald', 'tantyyellow' ),
						'source_sans_pro'       => esc_html__( 'Source Sans Pro', 'tantyyellow' ),
						'montserrat'            => esc_html__( 'Montserrat', 'tantyyellow' ),
						'raleway'               => esc_html__( 'Raleway', 'tantyyellow' ),
						'pt_sans'               => esc_html__( 'PT Sans', 'tantyyellow' ),
						'lora'                  => esc_html__( 'Lora', 'tantyyellow' ),
						'blank_en'              => '',
						'japanese_fonts'        => esc_html__( '*** JAPANESE FONTS ***', 'tantyyellow' ),
						'corporate_logo_bold'   => esc_html__( 'Corporate Logo Bold', 'tantyyellow' ),
						'corporate_logo_medium' => esc_html__( 'Corporate Logo Medium', 'tantyyellow' ),
						'noto_sans_jp'          => esc_html__( 'Noto Sans JP', 'tantyyellow' ),
						'noto_serif_jp'         => esc_html__( 'Noto Serif JP', 'tantyyellow' ),
						'm_plus_1p'             => esc_html__( 'M PLUS 1p', 'tantyyellow' ),
						'm_plus_rounded_1c'     => esc_html__( 'M PLUS Rounded 1c', 'tantyyellow' ),
						'sawarabi_gothic'       => esc_html__( 'Sawarabi Gothic', 'tantyyellow' ),
						'sawarabi_mincho'       => esc_html__( 'Sawarabi Mincho', 'tantyyellow' ),
						'blank_ja'              => '',
					),
				)
			);

}
add_action( 'customize_register', 'tantyyellow_theme_customizer_register_fonts' );



/**
 * Define function for action hook "wp_head".
 * 01. Retrieve the value of fonts put in the "Fonts" customizer panel and set its default value.
 * 02. Apply fonts styles to DOM content.
 */
function tantyyellow_theme_customizer_css_fonts() {

	/* ===== Font-family of 'Heading' level ===================================================== */
	$general_font_family_heading = get_theme_mod(
		'general_font_family_heading_setting',
		'corporate_logo_bold'
	);

	/* ===== Font-family of 'Sub Heading' level ================================================= */
	$general_font_family_subheading = get_theme_mod(
		'general_font_family_subheading_setting',
		'corporate_logo_medium'
	);

	/* ===== Font-family of 'Paragraph' level =================================================== */
	$general_font_family_paragraph = get_theme_mod(
		'general_font_family_paragraph_setting',
		'genJyuu_gothic'
	);

	/* ===== key:selected value / value:font-family ============================================= */
	$font_name_from_selected_value = array(
		'heading_default'       => 'Corporate_Logo_Bold',
		'subheading_default'    => 'Corporate_Logo_Medium',
		'paragraph_default'     => 'GenJyuu_Gothic',
		'lato'                  => 'Lato',
		'slabo_27px'            => 'Slabo 27px',
		'oswald'                => 'Oswald',
		'source_sans_pro'       => 'Source Sans Pro',
		'montserrat'            => 'Montserrat',
		'raleway'               => 'Raleway',
		'pt_sans'               => 'PT Sans',
		'lora'                  => 'Lora',
		'corporate_logo_bold'   => 'Corporate_Logo_Bold',
		'corporate_logo_medium' => 'Corporate_Logo_Medium',
		'genJyuu_gothic'        => 'GenJyuu_Gothic',
		'noto_sans_jp'          => 'Noto Sans JP',
		'noto_serif_jp'         => 'Noto Serif JP',
		'm_plus_1p'             => 'M PLUS 1p',
		'm_plus_rounded_1c'     => 'M PLUS Rounded 1c',
		'sawarabi_gothic'       => 'Sawarabi Gothic',
		'sawarabi_mincho'       => 'Sawarabi Mincho',
		'default_font'          => '',
		'english_fonts'         => '',
		'japanese_fonts'        => '',
		'blank_default'         => '',
		'blank_en'              => '',
		'blank_ja'              => '',
	);

	?>



	<style type="text/css">

		/* ===== Font-family of 'Heading' level ===================================================== */
		.font-family_heading_level,
		div.contents div#contents-main header.contents-header h1,
		.posts-loop main.row div.posts-loop-wrapper article.post-loop header.each-post-header div.each-post-header-inner div.each-post-info h2.each-post-title,
		.posts-loop.loop-sub#posts-loop-sub-is-single-page main.row div.posts-loop-wrapper article.post-loop header.each-post-header div.each-post-header-inner div.each-post-info h2.each-post-title,
		main#main #site-main-page-first-section #site-main-page-branding ul li h2#site-main-page-title,
		div.contact_page_items_wrapper section.contact_page_item div.contact_page_item_inner#contact_page_members_inner div#contact_page_members_contents main#contact_page_members_contents_inner div.contact_page_each_member div.contact_page_each_member_details h4.contact_page_each_member_position,
		div.contact_page_items_wrapper section.contact_page_item div.contact_page_item_inner#contact_page_members_inner div#contact_page_members_contents main#contact_page_members_contents_inner div.contact_page_each_member div.contact_page_each_member_details h3.contact_page_each_member_name {
			font-family: "<?php echo esc_attr( $font_name_from_selected_value[ $general_font_family_heading ] ); ?>" !important;
			font-weight: 900 !important;
		}

		/* ===== Font-family of 'Sub Heading' level ================================================= */
		.font-family_subheading_level,
		.widget-title,
		div#header-nav.page-wrapper,
		div.contents-sidebar div#sidebar-widgets-rightside-toggle-btn-wrapper p,
		div.contents-sidebar div.contents-sidebar-wrapper div.contents-sidebar-inner aside.sidebar section.widget h5.widget-title,
		#footer div#footer-page-top-btn a p,
		div.comment-wrapper div.comment-form-wrapper div.comment-respond h3#reply-title,
		div.comment-wrapper div.comment-form-wrapper div.comment-respond form#comment-form p.logged-in-as span.log-out-btn a,
		div.comment-wrapper div.comment-each-item h3.comment-each-item-list-title,
		div.comment-wrapper div.comment-each-item div.comment-each-item-list-pagination-wrapper p.comment-each-item-list-pagination a,
		nav#breadcrumb ul li,
		.posts-loop main.row div.posts-loop-wrapper article.post-loop div.each-post-main div.each-post-meta p span.each-post-meta-name,
		.posts-loop.loop-sub#posts-loop-sub-is-single-page main.row div.posts-loop-wrapper article.post-loop div.each-post-main div.each-post-meta p span.each-post-meta-name,
		.posts-loop#posts-loop-single-is-single-page main.row div.posts-loop-wrapper div#each-post-related-posts h2#each-post-related-posts-header,
		div.pagination-single p span a,
		div.contents.is_custom_page div#contents-main div.custom_page_sections_wrapper div.custom_page_item h2.custom_page_item_title,
		main#main #site-main-page-first-section #site-main-page-branding ul li p {
			font-family: "<?php echo esc_attr( $font_name_from_selected_value[ $general_font_family_subheading ] ); ?>" !important;
			font-weight: 700 !important;
		}

		/* ===== Font-family of 'Paragraph' level =================================================== */
		html,
		.each-post-meta-primary:before,
		.each-post-meta-secondary:before,
		.each-post-meta-thirdary:before,
		.each-post-meta-forthary:before{
			font-family: "<?php echo esc_attr( $font_name_from_selected_value[ $general_font_family_paragraph ] ); ?>" !important;
			font-weight: normal !important;
		}

	</style>

	<?php
} /* End of 'function tantyyellow_theme_customizer_css_fonts()' */

add_action( 'wp_head', 'tantyyellow_theme_customizer_css_fonts' );
