<?php
/**
 * "theme-customizer-site-basic.php"
 *
 * @package tantyyellow
 */

// ########################################################################################################################
// ##### Functions for 'Site Basic Settings' to customize theme ( Priority: 21 ) ##########################################
// ########################################################################################################################

/**
 * Define function for action hook "customize_register".
 * - Register theme customizer for "Site Basic Settings" section.
 *
 * @param WP_Customize_Manager $wp_customize Customizer object, which is an instance of the WP_Customize_Manager class.
 *
 * @link https://github.com/WPTT/code-examples/blob/master/customizer/sanitization-callbacks.php#L226 "Sanitize Number Range"
 */
function tantyyellow_theme_customizer_register_site_basics( $wp_customize ) {

	// Enable customizer Panel & Section to nest deeper.
	$wp_customize->register_panel_type( 'Tantyyellow_WP_Customize_Panel' );
	$wp_customize->register_section_type( 'Tantyyellow_WP_Customize_Section' );

	// **************************************************************************************************************
	// ***** Site Basic Settings Panel ******************************************************************************
	// **************************************************************************************************************
	$wp_customize->add_panel(
		'site_basics_panel',
		array(
			'title'    => esc_html__( 'Site Basic Settings', 'tantyyellow' ),
			'priority' => 21,
		)
	);

		// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
		// +++++ Site Basic Settings Section for Pages ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
		$wp_customize->add_section(
			'site_basics_section_pages',
			array(
				'title'    => esc_html__( 'Pages Settings', 'tantyyellow' ),
				'panel'    => 'site_basics_panel',
				'priority' => 1,
			)
		);

			// +++++ Sub Section for The Custom Posts Number per Page +++++++++++++++++++++++++++++++
			$wp_customize->add_section(
				new Tantyyellow_WP_Customize_Section( // Create a sub-section under a section.
					$wp_customize,
					'site_basics_subsection_custom_posts_num_per_page',
					array(
						'title'       => esc_html__( 'Custom Posts Number per Page', 'tantyyellow' ),
						'section'     => 'site_basics_section_pages',
						'panel'       => 'site_basics_panel',
						'description' =>
							'<h4 class="subsection_each_post_archive_pages_desc_sec_title">' . esc_html__( 'Set the number of posts per page for archive pages divided into multiple pages.', 'tantyyellow' ) . '</h4>
						',
					)
				)
			);

				/* ===== Enable/Disable the settings for the number of each page's posts ===================== */
				$wp_customize->add_setting(
					'site_basics_subsection_custom_posts_num_per_page_onoff_setting',
					array(
						'default'           => 'off',
						'type'              => 'theme_mod',
						'transport'         => 'postMessage',
						'sanitize_callback' => 'tantyyellow_sanitize_select_radio_callback',
					)
				);

					$wp_customize->add_control(
						'site_basics_subsection_custom_posts_num_per_page_onoff_control',
						array(
							'label'       => esc_html__( 'Enable Custom Posts Number per Page', 'tantyyellow' ),
							'section'     => 'site_basics_subsection_custom_posts_num_per_page',
							'settings'    => 'site_basics_subsection_custom_posts_num_per_page_onoff_setting',
							'description' => '
								<ol>
									<li>
										<p>' . esc_html__( '"On"  --> Set custom posts number respectively.', 'tantyyellow' ) . '</p>
									</li>
									<li>
										<p>' . esc_html__( '"Off" --> The default setting "Blog pages show at most" in "Dashboard --> Settings --> Reading" will apply to all archive pages.', 'tantyyellow' ) . '</p>
									</li>
								</ol>
							',
							'type'        => 'radio',
							'choices'     => array(
								'on'  => 'On',
								'off' => 'Off',
							),
						)
					);

				/* ===== The number of home page's posts ===================================================== */
				$wp_customize->add_setting(
					'site_basics_subsection_custom_posts_num_per_page_home_setting',
					array(
						'default'           => 12,
						'type'              => 'theme_mod',
						'transport'         => 'postMessage',
						'sanitize_callback' => 'absint',
					)
				);

					$wp_customize->add_control(
						new Tantyyellow_Customizer_Range_Control(
							$wp_customize,
							'site_basics_subsection_custom_posts_num_per_page_home_control',
							array(
								'label'       => esc_html__( 'Recent Posts Page', 'tantyyellow' ),
								'section'     => 'site_basics_subsection_custom_posts_num_per_page',
								'settings'    => 'site_basics_subsection_custom_posts_num_per_page_home_setting',
								'type'        => 'number',
								'input_attrs' => array(
									'min'  => 3,
									'max'  => 50,
									'step' => 1,
								),
							)
						)
					);

				/* ===== The number of search page's posts =================================================== */
				$wp_customize->add_setting(
					'site_basics_subsection_custom_posts_num_per_page_search_results_setting',
					array(
						'default'           => 10,
						'type'              => 'theme_mod',
						'transport'         => 'postMessage',
						'sanitize_callback' => 'absint',
					)
				);

					$wp_customize->add_control(
						new Tantyyellow_Customizer_Range_Control(
							$wp_customize,
							'site_basics_subsection_custom_posts_num_per_page_search_results_control',
							array(
								'label'       => esc_html__( 'Search Results Page', 'tantyyellow' ),
								'section'     => 'site_basics_subsection_custom_posts_num_per_page',
								'settings'    => 'site_basics_subsection_custom_posts_num_per_page_search_results_setting',
								'type'        => 'number',
								'input_attrs' => array(
									'min'  => 3,
									'max'  => 50,
									'step' => 1,
								),
							)
						)
					);

				/* ===== The number of category page's posts ================================================= */
				$wp_customize->add_setting(
					'site_basics_subsection_custom_posts_num_per_page_cat_archive_setting',
					array(
						'default'           => 15,
						'type'              => 'theme_mod',
						'transport'         => 'postMessage',
						'sanitize_callback' => 'absint',
					)
				);

					$wp_customize->add_control(
						new Tantyyellow_Customizer_Range_Control(
							$wp_customize,
							'site_basics_subsection_custom_posts_num_per_page_cat_archive_control',
							array(
								'label'       => esc_html__( 'Category Archive Page', 'tantyyellow' ),
								'section'     => 'site_basics_subsection_custom_posts_num_per_page',
								'settings'    => 'site_basics_subsection_custom_posts_num_per_page_cat_archive_setting',
								'type'        => 'number',
								'input_attrs' => array(
									'min'  => 3,
									'max'  => 50,
									'step' => 1,
								),
							)
						)
					);

				/* ===== The number of tag page's posts ====================================================== */
				$wp_customize->add_setting(
					'site_basics_subsection_custom_posts_num_per_page_tag_archive_setting',
					array(
						'default'           => 15,
						'type'              => 'theme_mod',
						'transport'         => 'postMessage',
						'sanitize_callback' => 'absint',
					)
				);

					$wp_customize->add_control(
						new Tantyyellow_Customizer_Range_Control(
							$wp_customize,
							'site_basics_subsection_custom_posts_num_per_page_tag_archive_control',
							array(
								'label'       => esc_html__( 'Tag Archive Page', 'tantyyellow' ),
								'section'     => 'site_basics_subsection_custom_posts_num_per_page',
								'settings'    => 'site_basics_subsection_custom_posts_num_per_page_tag_archive_setting',
								'type'        => 'number',
								'input_attrs' => array(
									'min'  => 3,
									'max'  => 50,
									'step' => 1,
								),
							)
						)
					);

				/* ===== The number of author page's posts =================================================== */
				$wp_customize->add_setting(
					'site_basics_subsection_custom_posts_num_per_page_author_archive_setting',
					array(
						'default'           => 15,
						'type'              => 'theme_mod',
						'transport'         => 'postMessage',
						'sanitize_callback' => 'absint',
					)
				);

					$wp_customize->add_control(
						new Tantyyellow_Customizer_Range_Control(
							$wp_customize,
							'site_basics_subsection_custom_posts_num_per_page_author_archive_control',
							array(
								'label'       => esc_html__( 'Author Archive Page', 'tantyyellow' ),
								'section'     => 'site_basics_subsection_custom_posts_num_per_page',
								'settings'    => 'site_basics_subsection_custom_posts_num_per_page_author_archive_setting',
								'type'        => 'number',
								'input_attrs' => array(
									'min'  => 3,
									'max'  => 50,
									'step' => 1,
								),
							)
						)
					);

				/* ===== The number of day page's posts ====================================================== */
				$wp_customize->add_setting(
					'site_basics_subsection_custom_posts_num_per_page_day_archive_setting',
					array(
						'default'           => 15,
						'type'              => 'theme_mod',
						'transport'         => 'postMessage',
						'sanitize_callback' => 'absint',
					)
				);

					$wp_customize->add_control(
						new Tantyyellow_Customizer_Range_Control(
							$wp_customize,
							'site_basics_subsection_custom_posts_num_per_page_day_archive_control',
							array(
								'label'       => esc_html__( 'Day Archive Page', 'tantyyellow' ),
								'section'     => 'site_basics_subsection_custom_posts_num_per_page',
								'settings'    => 'site_basics_subsection_custom_posts_num_per_page_day_archive_setting',
								'type'        => 'number',
								'input_attrs' => array(
									'min'  => 3,
									'max'  => 50,
									'step' => 1,
								),
							)
						)
					);

				/* ===== The number of month page's posts ==================================================== */
				$wp_customize->add_setting(
					'site_basics_subsection_custom_posts_num_per_page_month_archive_setting',
					array(
						'default'           => 15,
						'type'              => 'theme_mod',
						'transport'         => 'postMessage',
						'sanitize_callback' => 'absint',
					)
				);

					$wp_customize->add_control(
						new Tantyyellow_Customizer_Range_Control(
							$wp_customize,
							'site_basics_subsection_custom_posts_num_per_page_month_archive_control',
							array(
								'label'       => esc_html__( 'Month Archive Page', 'tantyyellow' ),
								'section'     => 'site_basics_subsection_custom_posts_num_per_page',
								'settings'    => 'site_basics_subsection_custom_posts_num_per_page_month_archive_setting',
								'type'        => 'number',
								'input_attrs' => array(
									'min'  => 3,
									'max'  => 50,
									'step' => 1,
								),
							)
						)
					);

				/* ===== The number of year page's posts ===================================================== */
				$wp_customize->add_setting(
					'site_basics_subsection_custom_posts_num_per_page_year_archive_setting',
					array(
						'default'           => 15,
						'type'              => 'theme_mod',
						'transport'         => 'postMessage',
						'sanitize_callback' => 'absint',
					)
				);

					$wp_customize->add_control(
						new Tantyyellow_Customizer_Range_Control(
							$wp_customize,
							'site_basics_subsection_custom_posts_num_per_page_year_archive_control',
							array(
								'label'       => esc_html__( 'Year Archive Page', 'tantyyellow' ),
								'section'     => 'site_basics_subsection_custom_posts_num_per_page',
								'settings'    => 'site_basics_subsection_custom_posts_num_per_page_year_archive_setting',
								'type'        => 'number',
								'input_attrs' => array(
									'min'  => 3,
									'max'  => 50,
									'step' => 1,
								),
							)
						)
					);

		// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
		// +++++ Site Basic Settings Section for Posts ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
		$wp_customize->add_section(
			'site_basics_section_posts',
			array(
				'title'    => esc_html__( 'Posts Settings', 'tantyyellow' ),
				'panel'    => 'site_basics_panel',
				'priority' => 2,
			)
		);

			// +++++ Sub Section for All Posts ++++++++++++++++++++++++++++++++++++++++++++++++++++++
			$wp_customize->add_section(
				new Tantyyellow_WP_Customize_Section( // Create a sub-section under a section.
					$wp_customize,
					'site_basics_section_posts_subsection_all_posts',
					array(
						'title'       => esc_html__( 'All Posts Settings', 'tantyyellow' ),
						'section'     => 'site_basics_section_posts',
						'panel'       => 'site_basics_panel',
						'description' =>
							'<h4 class="subsection_each_post_archive_pages_desc_sec_title">' . esc_html__( 'Will be applied to all pages.', 'tantyyellow' ) . '</h4>
						',
					)
				)
			);

				/* ===== Default Image ( which will be displayed when the featured image is not set. ) ======= */
				$wp_customize->add_setting(
					'site_basics_posts_subsection_all_posts_site_default_featured_img_setting',
					array(
						'default'           => get_theme_file_uri( '/src/assets/media-files/images/default_images/default_no_image.jpg' ),
						'type'              => 'theme_mod',
						'sanitize_callback' => 'tantyyellow_sanitize_image_ctrl_callback',
					)
				);

					$wp_customize->add_control(
						new WP_Customize_Image_Control(
							$wp_customize,
							'site_basics_posts_subsection_all_posts_site_default_featured_img_control',
							array(
								'label'       => esc_html__( 'Default Featured Image', 'tantyyellow' ),
								'section'     => 'site_basics_section_posts_subsection_all_posts',
								'settings'    => 'site_basics_posts_subsection_all_posts_site_default_featured_img_setting',
								'description' =>
									esc_html__( 'This image will be used only when a "Featured Image" is not defined at the right or "Default Image" is selected at the bottom in the post/page editting page for a display type.', 'tantyyellow' ),
							)
						)
					);

				/* ===== The badge name of sticky posts ====================================================== */
				$wp_customize->add_setting(
					'site_basics_posts_subsection_all_posts_sticky_posts_badge_name_setting',
					array(
						'default'           => esc_html__( 'SPECIAL!', 'tantyyellow' ),
						'type'              => 'theme_mod',
						'transport'         => 'postMessage',
						'sanitize_callback' => 'sanitize_text_field',
					)
				);

					$wp_customize->add_control(
						'site_basics_posts_subsection_all_posts_sticky_posts_badge_name_control',
						array(
							'label'       => esc_html__( 'Sticky Post\'s Badge', 'tantyyellow' ),
							'section'     => 'site_basics_section_posts_subsection_all_posts',
							'settings'    => 'site_basics_posts_subsection_all_posts_sticky_posts_badge_name_setting',
							'description' =>
								esc_html__( 'Set the name of the badge, which will be attached if "Stick to the top of the blog" checkbox is checked in the post edit page.', 'tantyyellow' ) .
								'<a href="' . get_theme_file_uri( '/src/assets/media-files/images/customizer_images/whats_badge_for_sticky_posts.jpg' ) . '" target="_blank">
									<img src="' . get_theme_file_uri( '/src/assets/media-files/images/customizer_images/whats_badge_for_sticky_posts.jpg' ) . '" style="margin: 10px 5%; width: 90%;">
								</a>
							',
							'type'        => 'text',
						)
					);

			// +++++ Sub Section for Each Post in Single Post Page ++++++++++++++++++++++++++++++++++
			$wp_customize->add_section(
				new Tantyyellow_WP_Customize_Section( // Create a sub-section under a section.
					$wp_customize,
					'site_basics_section_posts_subsection_each_post_single_page',
					array(
						'title'       => esc_html__( 'Each Post Settings', 'tantyyellow' ),
						'section'     => 'site_basics_section_posts',
						'panel'       => 'site_basics_panel',
						'description' =>
							'<h4 class="subsection_each_post_archive_pages_desc_sec_title">' . esc_html__( 'Will be applied to each single post page.', 'tantyyellow' ) . '</h4>
						',
					)
				)
			);

				/* ===== On/Off Each Post Meta Info Visibility =============================================== */
				$wp_customize->add_setting(
					'site_basics_posts_each_post_single_page_meta_info_visibility_setting',
					array(
						'default'           => 'show',
						'type'              => 'theme_mod',
						'transport'         => 'postMessage',
						'sanitize_callback' => 'tantyyellow_sanitize_select_radio_callback',
					)
				);

					$wp_customize->add_control(
						'site_basics_posts_each_post_single_page_meta_info_visibility_control',
						array(
							'label'       => esc_html__( 'Post Meta Info', 'tantyyellow' ),
							'section'     => 'site_basics_section_posts_subsection_each_post_single_page',
							'settings'    => 'site_basics_posts_each_post_single_page_meta_info_visibility_setting',
							'description' => esc_html__( 'Meta info for Each Single Post : "Categories", "Tags", "Author" & "Comments Number".', 'tantyyellow' ),
							'type'        => 'radio',
							'choices'     => array(
								'show' => esc_html__( 'Show', 'tantyyellow' ),
								'hide' => esc_html__( 'Hide', 'tantyyellow' ),
							),
						)
					);

			// +++++ Sub Section for Each Post in Archive Pages +++++++++++++++++++++++++++++++++++++
			$wp_customize->add_section(
				new Tantyyellow_WP_Customize_Section( // Create a sub-section under a section.
					$wp_customize,
					'site_basics_section_posts_subsection_each_post_archive_pages',
					array(
						'title'       => esc_html__( 'Each Post Settings ( Archive Pages )', 'tantyyellow' ),
						'section'     => 'site_basics_section_posts',
						'panel'       => 'site_basics_panel',
						'description' =>
							'<h4 class="subsection_each_post_archive_pages_desc_sec_title">' . esc_html__( 'Will be applied to all archive pages.', 'tantyyellow' ) . '</h4>' .
							'<ol class="subsection_each_post_archive_pages_desc_sec_desc">' .
								'<li class="subsection_each_post_archive_pages_desc_sec_desc_each"><em>' . esc_html__( 'Archive Pages : Recent-Posts / Sort-Posts / Site-Main / Search-Result / Category / Tag / Date, etc...', 'tantyyellow' ) . '</em></li>' .
								'<li class="subsection_each_post_archive_pages_desc_sec_desc_each"><em>' . esc_html__( 'Excerpt Length : Calculated by either the number of words or letters based on your language environment.', 'tantyyellow' ) . '</em></li>' .
							'</ol>
						',
					)
				)
			);

				/* ===== On/Off Each Post Meta Info Visibility =============================================== */
				$wp_customize->add_setting(
					'site_basics_posts_each_post_archive_pages_meta_info_visibility_setting',
					array(
						'default'           => 'show',
						'type'              => 'theme_mod',
						'transport'         => 'postMessage',
						'sanitize_callback' => 'tantyyellow_sanitize_select_radio_callback',
					)
				);

					$wp_customize->add_control(
						'site_basics_posts_each_post_archive_pages_meta_info_visibility_control',
						array(
							'label'       => esc_html__( 'Each Post Meta Info', 'tantyyellow' ),
							'section'     => 'site_basics_section_posts_subsection_each_post_archive_pages',
							'settings'    => 'site_basics_posts_each_post_archive_pages_meta_info_visibility_setting',
							'description' => esc_html__( 'Meta info for Archive Pages : "Categories" & "Tags".', 'tantyyellow' ),
							'type'        => 'radio',
							'choices'     => array(
								'show' => esc_html__( 'Show', 'tantyyellow' ),
								'hide' => esc_html__( 'Hide', 'tantyyellow' ),
							),
						)
					);

				/* ===== On/Off Custom Excerpt Length ======================================================== */
				$wp_customize->add_setting(
					'site_basics_posts_each_post_archive_pages_excerpt_length_custom_length_setting',
					array(
						'default'           => 'off',
						'type'              => 'theme_mod',
						'transport'         => 'postMessage',
						'sanitize_callback' => 'tantyyellow_sanitize_select_radio_callback',
					)
				);

					$wp_customize->add_control(
						'site_basics_posts_each_post_archive_pages_excerpt_length_custom_length_control',
						array(
							'label'       => esc_html__( 'Enable Custom Excerpt Length', 'tantyyellow' ),
							'section'     => 'site_basics_section_posts_subsection_each_post_archive_pages',
							'settings'    => 'site_basics_posts_each_post_archive_pages_excerpt_length_custom_length_setting',
							'description' => esc_html__( '"On" for activating custom length defined below, and "Off" for using theme default.', 'tantyyellow' ),
							'type'        => 'radio',
							'choices'     => array(
								'on'  => esc_html__( 'On', 'tantyyellow' ),
								'off' => esc_html__( 'Off', 'tantyyellow' ),
							),
						)
					);

				/* ===== Post Excerpt Length ================================================================= */
				$wp_customize->add_setting(
					'site_basics_posts_each_post_archive_pages_excerpt_length_setting',
					array(
						'default'           => 55,
						'type'              => 'theme_mod',
						'transport'         => 'postMessage',
						'sanitize_callback' => 'absint',
					)
				);

					$wp_customize->add_control(
						new Tantyyellow_Customizer_Range_Control(
							$wp_customize,
							'site_basics_posts_each_post_archive_pages_excerpt_length_control',
							array(
								'label'       => esc_html__( 'Custom Excerpt Length', 'tantyyellow' ),
								'section'     => 'site_basics_section_posts_subsection_each_post_archive_pages',
								'settings'    => 'site_basics_posts_each_post_archive_pages_excerpt_length_setting',
								'type'        => 'number',
								'input_attrs' => array(
									'min'  => 10,
									'max'  => 300,
									'step' => 5,
								),
							)
						)
					);

		// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
		// +++++ Site Basic Settings Section for Links ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
		$wp_customize->add_section(
			'site_basics_section_links',
			array(
				'title'    => esc_html__( 'Links Settings', 'tantyyellow' ),
				'panel'    => 'site_basics_panel',
				'priority' => 3,
			)
		);

			/* ===== Whether show or hide an underline for link's text =================================== */
			$wp_customize->add_setting(
				'site_basics_links_text_underline_setting',
				array(
					'default'           => 'underline',
					'type'              => 'theme_mod',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'tantyyellow_sanitize_select_radio_callback',
				)
			);

				$wp_customize->add_control(
					'site_basics_links_text_underline_control',
					array(
						'label'    => esc_html__( 'Links Text-Underline', 'tantyyellow' ),
						'section'  => 'site_basics_section_links',
						'settings' => 'site_basics_links_text_underline_setting',
						'type'     => 'radio',
						'choices'  => array(
							'underline' => esc_html__( 'Show', 'tantyyellow' ),
							'none'      => esc_html__( 'Hide', 'tantyyellow' ),
						),
					)
				);

			/* ===== Whether show or hide an underline for link's text(hovered) ========================== */
			$wp_customize->add_setting(
				'site_basics_links_text_hovered_underline_setting',
				array(
					'default'           => 'underline',
					'type'              => 'theme_mod',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'tantyyellow_sanitize_select_radio_callback',
				)
			);

				$wp_customize->add_control(
					'site_basics_links_text_hovered_underline_control',
					array(
						'label'    => esc_html__( 'Links Text-Underline(Hovered)', 'tantyyellow' ),
						'section'  => 'site_basics_section_links',
						'settings' => 'site_basics_links_text_hovered_underline_setting',
						'type'     => 'radio',
						'choices'  => array(
							'underline' => esc_html__( 'Show', 'tantyyellow' ),
							'none'      => esc_html__( 'Hide', 'tantyyellow' ),
						),
					)
				);

		// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
		// +++++ Site Basic Settings Section for Auto Close Expanded Elements +++++++++++++++++++++++++++++++++
		$wp_customize->add_section(
			'site_basics_section_auto_close_expanded_elems',
			array(
				'title'       => esc_html__( 'Auto-close Settings', 'tantyyellow' ),
				'panel'       => 'site_basics_panel',
				'priority'    => 4,
				'description' => esc_html__( 'Auto-close the expanded element when its outside area is clicked, touched, or focused.', 'tantyyellow' ),
			)
		);

			/* ===== Radio button for header navigation menu to turn on & off Auto-close ================= */
			$wp_customize->add_setting(
				'site_basics_auto_close_expanded_left_burger_menu_onoff_setting',
				array(
					'default'           => 'on',
					'type'              => 'theme_mod',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'tantyyellow_sanitize_select_radio_callback',
				)
			);

				$wp_customize->add_control(
					'site_basics_auto_close_expanded_left_burger_menu_onoff_control',
					array(
						'label'    => esc_html__( 'Left Burger Memu', 'tantyyellow' ),
						'section'  => 'site_basics_section_auto_close_expanded_elems',
						'settings' => 'site_basics_auto_close_expanded_left_burger_menu_onoff_setting',
						'type'     => 'radio',
						'choices'  => array(
							'on'  => esc_html__( 'On', 'tantyyellow' ),
							'off' => esc_html__( 'Off', 'tantyyellow' ),
						),
					)
				);

			/* ===== Radio button for right widgets sidebar to turn on & off Auto-close ================== */
			$wp_customize->add_setting(
				'site_basics_auto_close_expanded_right_widgets_sidebar_onoff_setting',
				array(
					'default'           => 'on',
					'type'              => 'theme_mod',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'tantyyellow_sanitize_select_radio_callback',
				)
			);

				$wp_customize->add_control(
					'site_basics_auto_close_expanded_right_widgets_sidebar_onoff_control',
					array(
						'label'    => esc_html__( 'Right Widgets Sidebar', 'tantyyellow' ),
						'section'  => 'site_basics_section_auto_close_expanded_elems',
						'settings' => 'site_basics_auto_close_expanded_right_widgets_sidebar_onoff_setting',
						'type'     => 'radio',
						'choices'  => array(
							'on'  => esc_html__( 'On', 'tantyyellow' ),
							'off' => esc_html__( 'Off', 'tantyyellow' ),
						),
					)
				);

			/* ===== Radio button for single page categories list to turn on & off Auto-close ============ */
			$wp_customize->add_setting(
				'site_basics_auto_close_expanded_single_page_cats_list_onoff_setting',
				array(
					'default'           => 'on',
					'type'              => 'theme_mod',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'tantyyellow_sanitize_select_radio_callback',
				)
			);

				$wp_customize->add_control(
					'site_basics_auto_close_expanded_single_page_cats_list_onoff_control',
					array(
						'label'    => esc_html__( 'Post Page Content Categories List', 'tantyyellow' ),
						'section'  => 'site_basics_section_auto_close_expanded_elems',
						'settings' => 'site_basics_auto_close_expanded_single_page_cats_list_onoff_setting',
						'type'     => 'radio',
						'choices'  => array(
							'on'  => esc_html__( 'On', 'tantyyellow' ),
							'off' => esc_html__( 'Off', 'tantyyellow' ),
						),
					)
				);

			/* ===== Radio button for single page Tags list to turn on & off Auto-close ================== */
			$wp_customize->add_setting(
				'site_basics_auto_close_expanded_single_page_tags_list_onoff_setting',
				array(
					'default'           => 'on',
					'type'              => 'theme_mod',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'tantyyellow_sanitize_select_radio_callback',
				)
			);

				$wp_customize->add_control(
					'site_basics_auto_close_expanded_single_page_tags_list_onoff_control',
					array(
						'label'    => esc_html__( 'Post Page Content Tags List', 'tantyyellow' ),
						'section'  => 'site_basics_section_auto_close_expanded_elems',
						'settings' => 'site_basics_auto_close_expanded_single_page_tags_list_onoff_setting',
						'type'     => 'radio',
						'choices'  => array(
							'on'  => esc_html__( 'On', 'tantyyellow' ),
							'off' => esc_html__( 'Off', 'tantyyellow' ),
						),
					)
				);

			/* ===== Radio button for single page related posts to turn on & off Auto-close ============== */
			$wp_customize->add_setting(
				'site_basics_auto_close_expanded_single_page_related_posts_onoff_setting',
				array(
					'default'           => 'on',
					'type'              => 'theme_mod',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'tantyyellow_sanitize_select_radio_callback',
				)
			);

				$wp_customize->add_control(
					'site_basics_auto_close_expanded_single_page_related_posts_onoff_control',
					array(
						'label'    => esc_html__( 'Post Page Related Posts', 'tantyyellow' ),
						'section'  => 'site_basics_section_auto_close_expanded_elems',
						'settings' => 'site_basics_auto_close_expanded_single_page_related_posts_onoff_setting',
						'type'     => 'radio',
						'choices'  => array(
							'on'  => esc_html__( 'On', 'tantyyellow' ),
							'off' => esc_html__( 'Off', 'tantyyellow' ),
						),
					)
				);

			/* ===== Radio button for single page comments to turn on & off Auto-close =================== */
			$wp_customize->add_setting(
				'site_basics_auto_close_expanded_single_page_comments_onoff_setting',
				array(
					'default'           => 'on',
					'type'              => 'theme_mod',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'tantyyellow_sanitize_select_radio_callback',
				)
			);

				$wp_customize->add_control(
					'site_basics_auto_close_expanded_single_page_comments_onoff_control',
					array(
						'label'    => esc_html__( 'Post Page Comments', 'tantyyellow' ),
						'section'  => 'site_basics_section_auto_close_expanded_elems',
						'settings' => 'site_basics_auto_close_expanded_single_page_comments_onoff_setting',
						'type'     => 'radio',
						'choices'  => array(
							'on'  => esc_html__( 'On', 'tantyyellow' ),
							'off' => esc_html__( 'Off', 'tantyyellow' ),
						),
					)
				);

			/* ===== Radio button for single page tracks & pings to turn on & off Auto-close ============= */
			$wp_customize->add_setting(
				'site_basics_auto_close_expanded_single_page_pings_onoff_setting',
				array(
					'default'           => 'on',
					'type'              => 'theme_mod',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'tantyyellow_sanitize_select_radio_callback',
				)
			);

				$wp_customize->add_control(
					'site_basics_auto_close_expanded_single_page_pings_onoff_control',
					array(
						'label'    => esc_html__( 'Post Page Pingbacks & Trackbacks', 'tantyyellow' ),
						'section'  => 'site_basics_section_auto_close_expanded_elems',
						'settings' => 'site_basics_auto_close_expanded_single_page_pings_onoff_setting',
						'type'     => 'radio',
						'choices'  => array(
							'on'  => esc_html__( 'On', 'tantyyellow' ),
							'off' => esc_html__( 'Off', 'tantyyellow' ),
						),
					)
				);

}
add_action( 'customize_register', 'tantyyellow_theme_customizer_register_site_basics' );



// **************************************************************************************************************
// ***** Functions to get what a user inputs in "Theme Customizer" panel which is defined above. ****************
// **************************************************************************************************************

// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
// +++++ Site Basic Settings Section for Pages ++++++++++++++++++++++++++++++++++++++++++++++++++++++++

/**
 * Get the number of posts per page for "Recent Posts Page".
 *
 * @return string Number of posts per page.
 */
function tantyyellow_get_site_basics_subsection_custom_posts_num_per_page_onoff_value() {
	return get_theme_mod(
		'site_basics_subsection_custom_posts_num_per_page_onoff_setting',
		'off'
	);
}



/**
 * Get the number of posts per page for "Recent Posts Page".
 *
 * @return string Number of posts per page.
 */
function tantyyellow_get_site_basics_subsection_custom_posts_num_per_page_home_num() {
	return get_theme_mod(
		'site_basics_subsection_custom_posts_num_per_page_home_setting',
		12
	);
}



/**
 * Get the number of posts per page for "Search Results Page".
 *
 * @return string Number of posts per page.
 */
function tantyyellow_get_site_basics_subsection_custom_posts_num_per_page_search_results_num() {
	return get_theme_mod(
		'site_basics_subsection_custom_posts_num_per_page_search_results_setting',
		10
	);
}



/**
 * Get the number of posts per page for "Category Archive Page".
 *
 * @return string Number of posts per page.
 */
function tantyyellow_get_site_basics_subsection_custom_posts_num_per_page_cat_archive_num() {
	return get_theme_mod(
		'site_basics_subsection_custom_posts_num_per_page_cat_archive_setting',
		15
	);
}



/**
 * Get the number of posts per page for "Tag Archive Page".
 *
 * @return string Number of posts per page.
 */
function tantyyellow_get_site_basics_subsection_custom_posts_num_per_page_tag_archive_num() {
	return get_theme_mod(
		'site_basics_subsection_custom_posts_num_per_page_tag_archive_setting',
		15
	);
}



/**
 * Get the number of posts per page for "Author Archive Page".
 *
 * @return string Number of posts per page.
 */
function tantyyellow_get_site_basics_subsection_custom_posts_num_per_page_author_archive_num() {
	return get_theme_mod(
		'site_basics_subsection_custom_posts_num_per_page_author_archive_setting',
		15
	);
}



/**
 * Get the number of posts per page for "Day Archive Page".
 *
 * @return string Number of posts per page.
 */
function tantyyellow_get_site_basics_subsection_custom_posts_num_per_page_day_archive_num() {
	return get_theme_mod(
		'site_basics_subsection_custom_posts_num_per_page_day_archive_setting',
		15
	);
}



/**
 * Get the number of posts per page for "Month Archive Page".
 *
 * @return string Number of posts per page.
 */
function tantyyellow_get_site_basics_subsection_custom_posts_num_per_page_month_archive_num() {
	return get_theme_mod(
		'site_basics_subsection_custom_posts_num_per_page_month_archive_setting',
		15
	);
}



/**
 * Get the number of posts per page for "Year Archive Page".
 *
 * @return string Number of posts per page.
 */
function tantyyellow_get_site_basics_subsection_custom_posts_num_per_page_year_archive_num() {
	return get_theme_mod(
		'site_basics_subsection_custom_posts_num_per_page_year_archive_setting',
		15
	);
}



// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
// +++++ Site Basic Settings Section for Posts ++++++++++++++++++++++++++++++++++++++++++++++++++++++++

// +++++ Sub Section for All Posts ++++++++++++++++++++++++++++++++++++++++++++++++++++++

/**
 * Get Site Default Featured Image URL.
 *
 * @return string Site default featured image URL path.
 */
function tantyyellow_get_site_basics_posts_subsection_all_posts_site_default_featured_img_url() {
	return get_theme_mod(
		'site_basics_posts_subsection_all_posts_site_default_featured_img_setting',
		get_theme_file_uri( '/src/assets/media-files/images/default_images/default_no_image.jpg' )
	);
}



/**
 * Get the value of checked radio button of "Sticky Post's Badge" setting.
 *
 * @return string 'on' for enabling, and 'off' for disabling.
 */
function tantyyellow_get_site_basics_posts_subsection_all_posts_sticky_posts_badge_name_text() {
	return get_theme_mod(
		'site_basics_posts_subsection_all_posts_sticky_posts_badge_name_setting',
		esc_html__( 'Special', 'tantyyellow' )
	);
}



// +++++ Sub Section for Each Post in Single Post Page ++++++++++++++++++++++++++++++++++

/**
 * Get the value of meta info visibility in single post.
 *
 * @return string Visibility value of single post meta info.
 */
function tantyyellow_get_site_basics_posts_each_post_single_page_meta_info_visibility_onoff_value() {
	return get_theme_mod(
		'site_basics_posts_each_post_single_page_meta_info_visibility_setting',
		'show'
	);
}



// +++++ Sub Section for Each Post in Archive Pages +++++++++++++++++++++++++++++++++++++

/**
 * Get the value of meta info visibility in archive page.
 *
 * @return string Visibility value of single post meta info.
 */
function tantyyellow_get_site_basics_posts_each_post_archive_pages_meta_info_visibility_onoff_value() {
	return get_theme_mod(
		'site_basics_posts_each_post_archive_pages_meta_info_visibility_setting',
		'show'
	);
}



/**
 * Get the value of whether or not custom excerpt length is active.
 *
 * @return string Value of custom excerpt length.
 */
function tantyyellow_get_site_basics_posts_each_post_archive_pages_excerpt_length_custom_length_onoff_value() {
	return get_theme_mod(
		'site_basics_posts_each_post_archive_pages_excerpt_length_custom_length_setting',
		'off'
	);
}



/**
 * Get the number of excerpt length.
 *
 * @return string Number of custom excerpt length.
 */
function tantyyellow_get_site_basics_posts_each_post_archive_pages_excerpt_length_num() {
	return get_theme_mod(
		'site_basics_posts_each_post_archive_pages_excerpt_length_setting',
		55
	);
}



// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
// +++++ Site Basic Settings Section for Links ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
/**
 * Get the value of setting defining link's text underline.
 *
 * @return string 'hide' for hiding link's underline, and 'show' for showing it.
 */
function tantyyellow_get_site_basics_links_text_underline_hideshow_value() {
	return get_theme_mod(
		'site_basics_links_text_underline_setting',
		'underline'
	);
}

/**
 * Get the value of setting defining link's text underline(hovered).
 *
 * @return string 'hide' for hiding link's underline, and 'show' for showing it.
 */
function tantyyellow_get_site_basics_links_text_hovered_underline_hideshow_value() {
	return get_theme_mod(
		'site_basics_links_text_hovered_underline_setting',
		'underline'
	);
}



// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
// +++++ Site Basic Settings Section for Auto Close Expanded Elements +++++++++++++++++++++++++++++++++

/**
 * Get the value of checked radio button of "Left Burger Memu" setting.
 *
 * @return string 'on' for enabling, and 'off' for disabling.
 */
function tantyyellow_get_site_basics_auto_close_expanded_left_burger_menu_onoff_value() {
	return get_theme_mod(
		'site_basics_auto_close_expanded_left_burger_menu_onoff_setting',
		'on'
	);
}

/**
 * Get the value of checked radio button of "Right Widgets Sidebar" setting.
 *
 * @return string 'on' for enabling, and 'off' for disabling.
 */
function tantyyellow_get_site_basics_auto_close_expanded_right_widgets_sidebar_onoff_value() {
	return get_theme_mod(
		'site_basics_auto_close_expanded_right_widgets_sidebar_onoff_setting',
		'on'
	);
}

/**
 * Get the value of checked radio button of "Post Page Complete Categories List" setting.
 *
 * @return string 'on' for enabling, and 'off' for disabling.
 */
function tantyyellow_get_site_basics_auto_close_expanded_single_page_cats_list_onoff_value() {
	return get_theme_mod(
		'site_basics_auto_close_expanded_single_page_cats_list_onoff_setting',
		'on'
	);
}

/**
 * Get the value of checked radio button of "Post Page Complete Tags List" setting.
 *
 * @return string 'on' for enabling, and 'off' for disabling.
 */
function tantyyellow_get_site_basics_auto_close_expanded_single_page_tags_list_onoff_value() {
	return get_theme_mod(
		'site_basics_auto_close_expanded_single_page_tags_list_onoff_setting',
		'on'
	);
}

/**
 * Get the value of checked radio button of "Post Page Related Posts" setting.
 *
 * @return string 'on' for enabling, and 'off' for disabling.
 */
function tantyyellow_get_site_basics_auto_close_expanded_single_page_related_posts_onoff_value() {
	return get_theme_mod(
		'site_basics_auto_close_expanded_single_page_related_posts_onoff_setting',
		'on'
	);
}

/**
 * Get the value of checked radio button of "Post Page Comments" setting.
 *
 * @return string 'on' for enabling, and 'off' for disabling.
 */
function tantyyellow_get_site_basics_auto_close_expanded_single_page_comments_onoff_value() {
	return get_theme_mod(
		'site_basics_auto_close_expanded_single_page_comments_onoff_setting',
		'on'
	);
}

/**
 * Get the value of checked radio button of "Post Page Pingbacks & Trackbacks" setting.
 *
 * @return string 'on' for enabling, and 'off' for disabling.
 */
function tantyyellow_get_site_basics_auto_close_expanded_single_page_pings_onoff_value() {
	return get_theme_mod(
		'site_basics_auto_close_expanded_single_page_pings_onoff_setting',
		'on'
	);
}



/**
 * Define function for action hook "wp_head".
 * 01. Retrieve the value of site basics setting put in the "Site Basics" customizer panel and set its default value.
 * 02. Apply styles to DOM content.
 */
function tantyyellow_theme_customizer_css_site_basics() {

	/* ===== Whether show or hide an underline for link's text =================================== */
	$links_text_underline_hideshow_value = ( tantyyellow_get_site_basics_links_text_underline_hideshow_value() );

	/* ===== Whether show or hide an underline for link's text(hovered) ========================== */
	$links_text_hovered_underline_hideshow_value = tantyyellow_get_site_basics_links_text_hovered_underline_hideshow_value();

	?>



	<style type="text/css">

		/* ===== Whether show or hide an underline for link's text =================================== */
		a {
			text-decoration: <?php echo esc_attr( $links_text_underline_hideshow_value ); ?>;
		}

		a:hover,
		a:focus {
			text-decoration: <?php echo esc_attr( $links_text_hovered_underline_hideshow_value ); ?>;
		}

	</style>

	<?php
} /* End of 'function tantyyellow_theme_customizer_css_site_basics()' */

add_action( 'wp_head', 'tantyyellow_theme_customizer_css_site_basics' );
