<?php
/**
 * ./template-parts/contents/contents-heading.php
 * This template is used to display 'Heading Title' for each page
 *
 * @package tantyyellow
 */

// ########################################################################################################################
// ##### 'Heading Title' for each page ####################################################################################
// ########################################################################################################################
?>

<header class="contents-header">
	<?php
	tantyyellow_output_contents_heading_default_title( 'visible' );
	tantyyellow_output_contents_heading_default_subtitle();
	?>
</header><!-- /.contents-header -->



<?php
/**
 * Output heading title in each page/post.
 *
 * @param string $visibility 'visible' for "visibility: visible" & 'hidden' for "visibility: hidden".
 */
function tantyyellow_output_contents_heading_default_title( $visibility = 'visible' ) {

	$locale = get_locale();

	$visibility_class = '';
	if ( 'visible' === $visibility ) {
		$visibility_class = 'visibility_visible';
	} elseif ( 'hidden' === $visibility ) {
		$visibility_class = 'visibility_hidden';
	}

	/* ===== If current page is "single page"... ================================================ */
	if ( is_single() ) :
		?>
		<h1 class="page-title font-family_heading_level<?php echo ( ( 'ja' === $locale ) ? ' font_weight_bold' : '' ) . ' ' . esc_attr( $visibility_class ); ?> focusable_elem" aria-label="
			<?php
			printf(
				/* translators: %s: The title of the current post. */
				esc_attr__( 'Single Post Page title named: %s', 'tantyyellow' ),
				get_the_title() ? esc_attr( wp_strip_all_tags( get_the_title() ) ) : esc_html__( 'No Title', 'tantyyellow' )
			);
			?>
		" tabindex="0">
			<?php echo get_the_title() ? wp_kses_post( get_the_title() ) : esc_html__( 'No Title', 'tantyyellow' ); ?>
		</h1>



		<?php
		/* ===== If current page is "Posts Home Page"... ============================================ */
	elseif ( is_home() ) :

		$tantyyellow_title_for_contents_heading_homepage = esc_html__( 'POSTS', 'tantyyellow' );
		echo '
			<h1 class="page-title font-family_heading_level' . ( ( 'ja' === $locale ) ? ' font_weight_bold' : '' ) . ' ' . esc_attr( $visibility_class ) . ' focusable_elem" aria-label="' .
				sprintf(
					/* translators: %s: The title of the posts page. */
					esc_attr__( 'Posts Page title named: %s', 'tantyyellow' ),
					wp_kses_post( $tantyyellow_title_for_contents_heading_homepage )
				) .
			'" tabindex="0">' .
				wp_kses_post( $tantyyellow_title_for_contents_heading_homepage ) .
			'</h1>
		';

		/* ===== If current page is "Front Page" or "Static Page"... ================================ */
	elseif ( is_front_page() || is_page() ) :

		/* ----- If current page is just "page.php"... ------------------------------------ */
		$tantyyellow_title_for_contents_heading_just_page = ( get_the_title() ) ? get_the_title() : '';
		echo '
			<h1 class="page-title font-family_heading_level' . ( ( 'ja' === $locale ) ? ' font_weight_bold' : '' ) . ' ' . esc_attr( $visibility_class ) . ' focusable_elem" aria-label="' .
				sprintf(
					/* translators: %s: The title of the page. */
					esc_attr__( 'Page title named: %s', 'tantyyellow' ),
					wp_kses_post( wp_strip_all_tags( $tantyyellow_title_for_contents_heading_just_page ) )
				) .
			'" tabindex="0">' .
				wp_kses_post( $tantyyellow_title_for_contents_heading_just_page ) .
			'</h1>
		';

		/* ===== If current page is "search results page"... ======================================== */
	elseif ( is_search() ) :

		/* ----- If 'Locale'(Site Language) setting is 'Japanese'... ---------------------- */
		$tantyyellow_title_for_contents_heading_search_result_page =
		sprintf(
			/* translators: %s: Keyword for searching. */
			esc_attr__( 'Search Results for "%s"', 'tantyyellow' ),
			get_search_query( false )
		);

		echo '
			<h1 class="page-title font-family_heading_level' . ( ( 'ja' === $locale ) ? ' font_weight_bold' : '' ) . ' ' . esc_attr( $visibility_class ) . ' focusable_elem" aria-label="' .
				sprintf(
					/* translators: %s: The title of search page. */
					esc_attr__( 'Search Page title named: %s', 'tantyyellow' ),
					wp_kses_post( $tantyyellow_title_for_contents_heading_search_result_page )
				) .
			'" tabindex="0">' .
				wp_kses_post( $tantyyellow_title_for_contents_heading_search_result_page ) .
			'</h1>
		';

		/* ===== If current page is "404 Not Found page"... ========================================= */
	elseif ( is_404() ) :
		$tantyyellow_title_for_contents_heading_404_page = esc_html__( '404 Not Found', 'tantyyellow' );
		echo '
			<h1 class="page-title font-family_heading_level' . ( ( 'ja' === $locale ) ? ' font_weight_bold' : '' ) . ' ' . esc_attr( $visibility_class ) . ' focusable_elem" aria-label="' .
				sprintf(
					/* translators: %s: The title of 404 Not Found page. */
					esc_attr__( '%s Page', 'tantyyellow' ),
					esc_attr( $tantyyellow_title_for_contents_heading_404_page )
				) .
			'" tabindex="0">' .
				esc_html( $tantyyellow_title_for_contents_heading_404_page ) .
			'</h1>
		';

		/* ===== If current page is "archive page"... =============================================== */
	elseif ( is_archive() ) :
		$tantyyellow_archive_type_for_title_for_contents_heading = '';
		$date_unit = ( 'ja' === $locale ) ? esc_html__( 'betsu', 'tantyyellow' ) : '';

		/* ----- If current page is 'Category Page'... ------------------------------------ */
		if ( is_category() ) :
			$tantyyellow_archive_type_for_title_for_contents_heading = esc_html__( 'CATEGORY', 'tantyyellow' );

			/* ----- If current page is 'Tag Page'... ------------------------------------ */
		elseif ( is_tag() ) :
			$tantyyellow_archive_type_for_title_for_contents_heading = esc_html__( 'TAG', 'tantyyellow' );

			/* ----- If current page is 'Author Page'... ------------------------------------ */
		elseif ( is_author() ) :
			$tantyyellow_archive_type_for_title_for_contents_heading = esc_html__( 'AUTHOR', 'tantyyellow' );

			/* ----- If current page is 'Day Page'... ------------------------------------ */
		elseif ( is_day() ) :
			$tantyyellow_archive_type_for_title_for_contents_heading = esc_html__( 'DAY', 'tantyyellow' ) . $date_unit;

			/* ----- If current page is 'Month Page'... ------------------------------------ */
		elseif ( is_month() ) :
			$tantyyellow_archive_type_for_title_for_contents_heading = esc_html__( 'MONTH', 'tantyyellow' ) . $date_unit;

			/* ----- If current page is 'Year Page'... ------------------------------------ */
		elseif ( is_year() ) :
			$tantyyellow_archive_type_for_title_for_contents_heading = esc_html__( 'YEAR', 'tantyyellow' ) . $date_unit;

			/* ----- else --------------------------------------------------------------------- */
		else :
			$tantyyellow_archive_type_for_title_for_contents_heading = esc_html__( 'Archive', 'tantyyellow' );

		endif;

		the_archive_title(
			// Before title.
			'<h1 class=\'page-title font-family_heading_level' . ( ( 'ja' === $locale ) ? ' font_weight_bold' : '' ) . ' ' . esc_attr( $visibility_class ) . ' focusable_elem\' aria-label="' .
				sprintf(
					/* translators: %1$s: The type of archive / %2$s: The title of the page. */
					esc_attr__( '%1$s archive page title named: %2$s', 'tantyyellow' ),
					wp_kses_post( $tantyyellow_archive_type_for_title_for_contents_heading ),
					wp_kses_post( get_the_archive_title() )
				) .
			'" tabindex="0">' . esc_html__( ' "', 'tantyyellow' ),
			// After title.
			esc_html__( '" ', 'tantyyellow' ) . esc_html__( 'Archive', 'tantyyellow' ) . '</h1>'
		);

	endif;
}
?>



<?php
/**
 * Output heading subtitle in each page/post.
 */
function tantyyellow_output_contents_heading_default_subtitle() {

	global $wp_query;

	$locale = get_locale();

	/* ===== If current page is "single page"... ================================================ */
	if ( is_single() ) :
		return;

		/* ===== If current page is "Posts Home Page"... ============================================ */
	elseif ( is_home() ) :

		$tantyyellow_subtitle_for_contents_heading_homepage = esc_html__( 'Sorted by date', 'tantyyellow' );
		echo '
			<div><hr><h3 class="page-subtitle focusable_elem" aria-label="' . esc_attr__( 'Posts are sorted by date', 'tantyyellow' ) . '" tabindex="0">' .
					esc_html( $tantyyellow_subtitle_for_contents_heading_homepage ) .
			'</h3><hr></div>
		';

		/* ===== If current page is "search results page"... ======================================== */
	elseif ( is_search() ) :

		/* ----- If the number of posts is '0'... ----------------------------------------- */
		if ( 0 === $wp_query->found_posts ) :
			$tantyyellow_subtitle_for_contents_heading_search_result_page = esc_html__( 'No result has been found.', 'tantyyellow' );

			/* ----- If the number of posts is '1'... ----------------------------------------- */
		elseif ( 1 === $wp_query->found_posts ) :
			$tantyyellow_subtitle_for_contents_heading_search_result_page = esc_html__( 'One result has been found.', 'tantyyellow' );

			/* ----- If the number of posts are '2' or more... -------------------------------- */
		elseif ( 2 <= $wp_query->found_posts ) :
			$tantyyellow_subtitle_for_contents_heading_search_result_page = $wp_query->found_posts . esc_html__( ' results have been found.', 'tantyyellow' );

		endif;

		echo '
			<div><hr><h3 class="page-subtitle focusable_elem" aria-label="' .
				sprintf(
					/* translators: %s: The subtitle of search page. */
					esc_attr__( 'Search Page subtitle named: %s', 'tantyyellow' ),
					esc_attr( $tantyyellow_subtitle_for_contents_heading_search_result_page )
				) .
			'" tabindex="0">' .
				esc_html( $tantyyellow_subtitle_for_contents_heading_search_result_page ) .
			'</h3><hr></div>
		';

		/* ===== If current page is "404 Not Found page"... ========================================= */
	elseif ( is_404() ) :
		$tantyyellow_subtitle_for_contents_heading_404_page = esc_html__( 'Page not found', 'tantyyellow' );
		echo '
			<div><hr><h3 class="page-subtitle focusable_elem" aria-label="' . esc_attr__( 'No page are found', 'tantyyellow' ) . '" tabindex="0">' .
				esc_html( $tantyyellow_subtitle_for_contents_heading_404_page ) .
			'</h3><hr></div>
		';

		/* ===== If current page is "archive page"... =============================================== */
	elseif ( is_archive() ) :
		$tantyyellow_archive_type_for_subtitle_for_contents_heading = '';
		$date_unit = ( 'ja' === $locale ) ? esc_html__( 'betsu', 'tantyyellow' ) : '';

		/* ----- If current page is 'Category Page'... ------------------------------------ */
		if ( is_category() ) :
			$tantyyellow_archive_type_for_subtitle_for_contents_heading = esc_html__( 'CATEGORY', 'tantyyellow' );

			/* ----- If current page is 'Tag Page'... ------------------------------------ */
		elseif ( is_tag() ) :
			$tantyyellow_archive_type_for_subtitle_for_contents_heading = esc_html__( 'TAG', 'tantyyellow' );

			/* ----- If current page is 'Author Page'... ------------------------------------ */
		elseif ( is_author() ) :
			$tantyyellow_archive_type_for_subtitle_for_contents_heading = esc_html__( 'AUTHOR', 'tantyyellow' );

			/* ----- If current page is 'Day Page'... ------------------------------------ */
		elseif ( is_day() ) :
			$tantyyellow_archive_type_for_subtitle_for_contents_heading = esc_html__( 'DAY', 'tantyyellow' );

			/* ----- If current page is 'Month Page'... ------------------------------------ */
		elseif ( is_month() ) :
			$tantyyellow_archive_type_for_subtitle_for_contents_heading = esc_html__( 'MONTH', 'tantyyellow' );

			/* ----- If current page is 'Year Page'... ------------------------------------ */
		elseif ( is_year() ) :
			$tantyyellow_archive_type_for_subtitle_for_contents_heading = esc_html__( 'YEAR', 'tantyyellow' );

			/* ----- else --------------------------------------------------------------------- */
		else :
			$tantyyellow_archive_type_for_subtitle_for_contents_heading = esc_html__( 'Archive', 'tantyyellow' );

		endif;
		?>

		<?php
		$posts_num = $wp_query->found_posts;
		?>
		<div><hr><h3 class="page-subtitle focusable_elem" aria-label="
			<?php
			printf(
				/* translators: %1$s: The type of archive / %2$s: The number of posts. */
				esc_attr__( '%1$s archive page subtitle saying the number of posts in this archive is %2$s', 'tantyyellow' ),
				esc_attr( $tantyyellow_archive_type_for_subtitle_for_contents_heading ) . ( is_date() ? esc_attr( $date_unit ) : '' ),
				esc_attr( $posts_num )
			);
			?>
		" tabindex="0">
			<?php
			echo esc_html__( 'This ', 'tantyyellow' );

			/* ----- If the number of posts is '0'... ----------------------------------------- */
			if ( 0 === (int) $posts_num ) :
				echo esc_html( $tantyyellow_archive_type_for_subtitle_for_contents_heading ) . esc_html__( ' has no post.', 'tantyyellow' );

				/* ----- If the number of posts is '1'... ----------------------------------------- */
			elseif ( 1 === (int) $posts_num ) :
				echo esc_html( $tantyyellow_archive_type_for_subtitle_for_contents_heading ) . esc_html__( ' has one post.', 'tantyyellow' );

				/* ----- If the number of posts are '2' or more... -------------------------------- */
			elseif ( 2 <= (int) $posts_num ) :
				echo esc_html( $tantyyellow_archive_type_for_subtitle_for_contents_heading ) . esc_html__( ' has ', 'tantyyellow' ) . esc_html( $posts_num ) . esc_html__( ' posts.', 'tantyyellow' );

			endif;
			?>

		</h3><hr></div>
		<?php

	endif;
}
