<?php
/**
 * ./template-parts/loops/loop-sub.php
 * This template is used to display all posts under 'Sub Loop', such as "site-main-page.php", and "Related Posts" under single.php, and so on.
 *
 * @package tantyyellow
 */

// ########################################################################################################################
// ##### 'Sub Loop' #######################################################################################################
// ########################################################################################################################

/** ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/** +++++ In order to define 'Query' depending on current page +++++++++++++++++++++++++++++++++++++++++ */

if ( is_front_page() ) :
	$tantyyellow_new_wp_query_for_loop_sub = new WP_Query(
		array(
			'posts_per_page' => get_option( 'posts_per_page' ), /* Get the number of posts displayed on each page defined at "Admin Panel" */
			'orderby'        => 'post_date',
			'order'          => 'DESC',
			'post_type'      => 'post',
			'post_status'    => 'publish',
			'no_found_rows'  => true,
		)
	);

	// For the related posts list of a single post.
elseif ( is_single() ) :
	$tantyyellow_cats_for_loop_sub    = get_the_category( $post->ID );
	$tantyyellow_cats_id_for_loop_sub = array();

	foreach ( $tantyyellow_cats_for_loop_sub as $tantyyellow_each_category ) :
		array_push( $tantyyellow_cats_id_for_loop_sub, intval( $tantyyellow_each_category->cat_ID ) );
	endforeach;

	$tantyyellow_new_wp_query_for_loop_sub = new WP_Query(
		array(
			'post__not_in'   => array( $post->ID ),
			'category__in'   => $tantyyellow_cats_id_for_loop_sub,
			'posts_per_page' => 3,
			'orderby'        => 'date',
		)
	);

endif;



/** ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/** +++++ In order to output loop ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */

// ===== If there are post(s)... ============================================================
if ( $tantyyellow_new_wp_query_for_loop_sub->have_posts() ) :

	global $template;

	if ( is_single() ) :
		?>
		<section id="posts-loop-sub-is-single-page" class="posts-loop loop-sub has-posts container">
		<?php
	else :
		?>
		<section class="posts-loop loop-sub has-posts container">
		<?php
	endif;
	?>
	<main class="row">
	<?php


	while ( $tantyyellow_new_wp_query_for_loop_sub->have_posts() ) :
		$tantyyellow_new_wp_query_for_loop_sub->the_post();

		// For the related posts list of a single post.
		if ( is_single() ) :
			?>

			<div class="<?php echo ( is_sticky() ) ? 'sticky-post-wrapper' : ''; ?> posts-loop-wrapper container">

			<?php
			if ( is_sticky() ) :
				?>
				<span class="sticky-post">
					<?php
					if ( tantyyellow_get_site_basics_posts_subsection_all_posts_sticky_posts_badge_name_text() ) :
						echo esc_html( tantyyellow_get_site_basics_posts_subsection_all_posts_sticky_posts_badge_name_text() );
					endif;
					?>
				</span>
				<?php
			endif;
			?>

				<article id="post-<?php the_ID(); ?>" <?php post_class( 'post-loop excerpted-post row' ); ?>><!-- /article -->

					<!-- Each post header -->
					<header class="each-post-header col-md-5 col-lg-4">
						<div class="each-post-header-inner">
							<!-- Each post information -->
							<?php tantyyellow_output_template_parts_loop_each_post_infos( 'with-post-title', 'with-post-dates' ); ?>
							<!-- Each post background image. -->
							<?php tantyyellow_output_template_parts_loop_each_post_thumbnail_image( '' ); ?>
						</div>
					</header><!-- /.each-post-header -->

					<!-- Each post Main -->
					<div id="each-post-main-is-single" class="each-post-main col-md-7 col-lg-8">
						<!-- Each post meta information -->
						<?php tantyyellow_output_template_parts_loop_each_post_meta_infos(); ?>
						<!-- Each post content -->
						<?php tantyyellow_output_template_parts_loop_each_post_content( $post->post_content, 'with-details-link', 'sub_loop' ); ?>
					</div><!-- /.each-post-main -->

				</article><!-- /.posts-loop -->

			</div><!-- /.posts-loop-wrapper -->
			<?php



		else :
			?>

			<div class="<?php echo ( is_sticky() ) ? 'sticky-post-wrapper ' : ''; ?>posts-loop-wrapper">
				<?php tantyyellow_output_loop_sub_each_post( 'with-details-link', 'sub_loop' ); ?>
			</div><!-- /.posts-loop-wrapper -->

			<?php
		endif;



	endwhile;

	wp_reset_postdata(); /* In order to reset "Global variable" */
	?>

		</main><!-- /row -->

	</section><!-- /.posts-loop .container -->

	<?php
	/* ===== If there is no post... ============================================================= */
else :
	tantyyellow_output_template_parts_nothing_exists_message();


	/* ===== End of "have_posts()" ============================================================== */
endif;
