<?php
/**
 * ./template-parts/headers/header-body.php
 * This template is used to display <body> for "header.php"
 *
 * @package tantyyellow
 */

// ########################################################################################################################
// ##### For <body> for 'Header Template'(header.php) #####################################################################
// ########################################################################################################################

// ***** In order to output <body> elements *********************************************************************
?>

<body
<?php
echo ' ';
body_class( 'custom-background' );
echo ' ';
?>
id="
<?php
do_action( 'tantyyellow_add_id_to_body_tag' );
?>
">

<?php
/**
 * The link button "Skip to Main Content" is added by using add_action() named "wp_body_open".
 *
 * @see functions\outputs.php\tantyyellow_output_skip_link_button()
 */
if ( function_exists( 'wp_body_open' ) ) {
	wp_body_open();
} else {
	do_action( 'tantyyellow_wp_body_open' );
}



/** ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/** +++++  In order to show the alert massage "IE unsupported!" when IE is used ++++++++++++++++++++++++ */
if ( is_front_page() ) :
	?>
	<section id="alert_ie">
		<div>
			<div>
				<h2><?php esc_html_e( 'Internet Explorer Unsupported!', 'tantyyellow' ); ?></h2>
				<p><?php esc_html_e( 'This website will offer limited functionality in "Internet Explorer," which may cause critical issues. It is suggested to use the recent versions of major browsers.', 'tantyyellow' ); ?></p>
				<p><span class="major_browsers"><?php esc_html_e( 'Chrome, Firefox, Safari, or Edge', 'tantyyellow' ); ?></span><?php esc_html_e( ' is recommended', 'tantyyellow' ); ?>.</p>
			</div>
			<span id="close_alert_ie_btn"><i class="fas fa-times"></i></span>
		</div>
	</section>
	<?php
endif;
?>


<div id="site" class="<?php echo ( has_custom_logo() ) ? 'has-custom-logo' : 'has-no-custom-logo'; ?>">

	<div id="site-inner" class="">

		<?php
		/** ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
		/** +++++  01. In order to output 'Site Header Content' ++++++++++++++++++++++++++++++++++++++++++++++++ */
		?>

		<header id="site-header" role="banner">

			<!-- Header main contents -->
			<div id="site-header-inner">

				<!-- Header Menu -->
				<div id="header-nav" class="page-wrapper clearfix font-family_subheading_level chiller-theme"><!-- Add class "expanded" in order to appear "Side Menu" as default when "Header Menu" is collapsed. -->

					<?php
					if ( has_custom_logo() ) :
						?>
						<div id="header-logo" class="has-custom-logo" aria-label="<?php echo esc_attr__( 'Click this header logo to return the site homepage', 'tantyyellow' ); ?>">
							<?php
							the_custom_logo();

					else :
						?>
						<div id="header-logo" class="has-no-custom-logo" aria-label="<?php echo esc_attr__( 'Click this header logo to return the site homepage', 'tantyyellow' ); ?>">
							<a href="<?php echo esc_url( home_url() ); ?>" class="custom-logo-link" rel="home" itemprop="url">
								<span><?php bloginfo( 'name' ); ?></span>
							</a>

						<?php
					endif;
					?>

					</div><!-- /#header-logo -->

					<nav id="header-nav-sidebar-wrapper" class="navbar navbar-expand-sm navbar-dark sidebar-wrapper" role="navigation" aria-label="<?php esc_attr_e( 'Global Navigation Menu', 'tantyyellow' ); ?>">

						<!-- Burger Menu -->
						<button id="header-nav-toggle-btn" class="nav-open" aria-label="<?php echo esc_attr__( 'Click this burger button in order to expand or collapse the "Global Navigation Menu" at the left of the page', 'tantyyellow' ); ?>">
							<ul>
								<li></li>
								<li></li>
								<li></li>
							</ul>
						</button>

						<div id="" class="sidebar-content">

							<div id="" class="navbar-collapse sidebar-menu">

								<?php
								/**
								 * How to use "has_nav_menu( '$location' )"
								 * which determines whether a registered nav menu location has a menu assigned to it.
								 * - Without this validation, if no menu is assigned in the "Menus" settings under the "Appearance" tab,
								 *   the error message "Trying to get property 'before' of non-object in ....." shows up.
								 *
								 * @link https://developer.wordpress.org/reference/functions/has_nav_menu/
								 * @link https://developer.wordpress.org/reference/functions/get_nav_menu_locations/
								 * @link https://core.trac.wordpress.org/browser/tags/5.5.1/src/wp-includes/nav-menu.php#L165
								 * @link https://core.trac.wordpress.org/browser/tags/5.5.1/src/wp-includes/nav-menu.php#L178
								 * @link https://wordpress.stackexchange.com/questions/103148/error-trying-to-get-property-of-non-object-with-custom-walker-for-wp-nav-menu
								 */
								if ( has_nav_menu( 'header-navigation' ) ) {
									wp_nav_menu(
										array(
											'theme_location' => 'header-navigation',
											'container'  => 'false',
											'menu_id'    => 'header-nav-list', /* 'id=""' for <ul> in first hierarchy */
											'menu_class' => 'header-nav-list navbar-nav', /* 'class=""' for <ul> in first hierarchy */
											'before'     => '',
											'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s' . "\n" . str_repeat( "\t", 7 ) . '</ul>' . "\n",
											'walker'     => new Tantyyellow_Custom_Walker_Nav_Menu(),
										)
									);
								}
								?>

								<!-- Search form -->
								<div id="header-search-form" class="tantyyellow-search-form">
									<?php get_search_form(); /* Load 'searchform.php' */ ?>
								</div>

							</div><!-- /#main-nav-menu-header -->

						</div><!-- /#site-main-nav-content -->

					</nav><!-- /#site-main-nav -->

				</div><!-- /#header-nav -->

				<?php get_template_part( './template-parts/headers/header', 'bodybreadcrumb' ); ?>

			</div><!-- /#site-header-inner -->

		</header><!-- /#site-header -->



		<!-- ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ -->
		<!-- +++++  02. In order to output 'Site Main Content' ++++++++++++++++++++++++++++++++++++++++++++++++++ -->

		<main id="main" class="container <?php do_action( 'tantyyellow_add_classes_to_site_main_content' ); ?>" role="main">
		<!-- <main id="main" class="container" role="main"> -->
