<?php
/**
 * ./template-parts/headers/header-bodybreadcrumb.php
 * This template is used to display 'Breadcrumb List' in 'header-body.php' for "header.php"
 *
 * @package tantyyellow
 */

// ########################################################################################################################
// ##### For 'Breadcrumb List' in 'header-body.php' for 'Header Template'(header.php) #####################################
// ########################################################################################################################


// ***** In order to output 'Breadcrumb List' *******************************************************************

?>

<nav id="breadcrumb">

	<ul class="breadcrumb_inner_ul font-family_subheading_level" role="list" aria-label="<?php echo esc_attr__( 'This breadcrumb lists the links to this page\'s ancestral pages', 'tantyyellow' ); ?>">

	<?php
	( function() {

		global $post;

		$current_page_title = $post->post_title ? $post->post_title : '';

		if ( is_front_page() ) :
			?>
			<!-- Current page in a breadcrumb list -->
			<li role="listitem">
				<a aria-label="<?php echo esc_attr__( 'Current page is the site homepage', 'tantyyellow' ); ?>" tabindex="0"><?php esc_html_e( 'HOME', 'tantyyellow' ); ?></a>
			</li>
			<?php

		else :
			?>
			<!-- The link to the "Homepage" is added to all pages' breadcrumb list as the root page except for the "Homepage". -->
			<li role="listitem">

				<a href="<?php echo esc_url( home_url() ); ?>" aria-label="<?php echo esc_attr__( 'Site homepage', 'tantyyellow' ); ?>">
					<?php echo esc_html__( 'HOME', 'tantyyellow' ); ?>
				</a>

			</li>

			<li>&gt;</li>



			<?php
			/* ----- If the current page is "Posts Home" page... ------------------------------ */
			if ( is_home() ) :
				?>
				<!-- Current page in a breadcrumb list -->
				<li role="listitem">
					<a aria-label="<?php echo esc_attr__( 'Current page is the recent posts page', 'tantyyellow' ); ?>" tabindex="0">
						<?php esc_html_e( 'Recent Posts Page', 'tantyyellow' ); ?>
					</a>
				</li>



				<?php
				/* ===== If the current page is "Page"... =================================================== */
			elseif ( is_page() ) :

				if ( 0 !== $post->post_parent ) :

					$page_ancestors = array_reverse( get_ancestors( $post->ID, 'page' ) );

					foreach ( $page_ancestors as $page_ancestor ) :
						?>
						<li role="listitem">
							<a href="<?php echo esc_url( get_permalink( $page_ancestor ) ); ?>" aria-label="
								<?php
								printf(
									/* translators: %s: The title of the page. */
									esc_attr__( 'Page titled: "%s"', 'tantyyellow' ),
									esc_attr( wp_strip_all_tags( get_the_title( $page_ancestor ) ) )
								);
								?>
							">
								<?php echo wp_kses_post( get_the_title( $page_ancestor ) ); ?>
							</a>
						</li>

						<li>&gt;</li>
						<?php

					endforeach;

				endif;
				?>

				<!-- Current page in a breadcrumb list -->
				<li role="listitem">

					<a aria-label="
						<?php
						printf(
							/* translators: %s: The title of the current page. */
							esc_attr__( 'Current page is %s', 'tantyyellow' ),
							esc_attr( wp_strip_all_tags( $current_page_title ) )
						);
						?>
					" tabindex="0">
						<?php echo wp_kses_post( $current_page_title ); ?>
					</a>

				</li>



				<?php
				/* ----- If the current page is "Search" page... ---------------------------------- */
			elseif ( is_search() ) :
				?>
				<!-- Current page in a breadcrumb list -->
				<li role="listitem">

					<a aria-label="
						<?php
						printf(
							/* translators: %s: The keyword for the search results page. */
							esc_attr__( 'Current page is the search results page for the keyword: "%s"', 'tantyyellow' ),
							get_search_query( false )
						);
						?>
					" tabindex="0">

						<?php
						printf(
							/* translators: %s: The keyword for the search results page. */
							esc_attr__( 'Search Results for "%s"', 'tantyyellow' ),
							get_search_query( false )
						);
						?>

					</a>

				</li>
				<?php

				/* ----- If the current page is "Tag" page... ------------------------------------- */
			elseif ( is_tag() ) :
				?>
				<!-- Current page in a breadcrumb list -->
				<li role="listitem">

					<a aria-label="
						<?php
						printf(
							/* translators: %s: The title of the current page. */
							esc_attr__( 'Current page is the archive page of the tag: "%s"', 'tantyyellow' ),
							single_tag_title( '', false ) // Not output but return the value.
						);
						?>
					" tabindex="0">

						<?php
						echo esc_html__( 'Tag: ', 'tantyyellow' );
						single_tag_title();
						?>

					</a>

				</li>



				<?php
				/* ----- If the current page is "404" page... ------------------------------------- */
			elseif ( is_404() ) :
				?>
				<!-- Current page in a breadcrumb list -->
				<li role="listitem">

					<a aria-label="<?php echo esc_attr__( 'Current page is 404 not found page', 'tantyyellow' ); ?>" tabindex="0">
						<?php esc_html_e( '404 Not found', 'tantyyellow' ); ?>
					</a>

				</li>



				<?php
				/* ----- If the current page is "date" archive page... ---------------------------- */
			elseif ( is_date() ) :

				if ( is_day() ) :
					?>
					<li role="listitem">

						<a href="<?php echo esc_url( get_year_link( get_query_var( 'year' ) ) ); ?>" aria-label="
							<?php
							printf(
								/* translators: %s: The title of the page. */
								esc_attr__( 'Archive page of the year: "%s"', 'tantyyellow' ),
								esc_attr( get_query_var( 'year' ) )
							);
							?>
						">

							<?php echo esc_html( get_query_var( 'year' ) ); ?>
							<?php echo ( ( 'ja' === get_locale() ) ? esc_html__( 'seireki', 'tantyyellow' ) : '' ); ?>

						</a>

					</li>

					<li>&gt;</li>

					<li role="listitem">

						<a href="<?php echo esc_url( get_month_link( get_query_var( 'year' ), esc_html( get_query_var( 'monthnum' ) ) ) ); ?>" aria-label="
							<?php
							printf(
								/* translators: %s: The title of the page. */
								esc_attr__( 'Archive page of the month: "%2$s %1$s"', 'tantyyellow' ),
								esc_attr( get_query_var( 'year' ) ),
								esc_attr( $GLOBALS['wp_locale']->get_month( get_query_var( 'monthnum' ) ) )
							);
							?>
						">

							<?php echo esc_html( $GLOBALS['wp_locale']->get_month( get_query_var( 'monthnum' ) ) ); ?>

						</a>

					</li>

					<li>&gt;</li>

					<?php
					$day = get_query_var( 'day' );

					$day_num         = intval( $day );
					$day_num_ordinal = '';

					if ( '11' === $day || '12' === $day ) {
						$day_num_ordinal = esc_html__( 'th', 'tantyyellow' );
					} else {

						switch ( $day % 10 ) :
							case 1:
								$day_num_ordinal = esc_html__( 'st', 'tantyyellow' );
								break;

							case 2:
								$day_num_ordinal = esc_html__( 'nd', 'tantyyellow' );
								break;

							case 3:
								$day_num_ordinal = esc_html__( 'rd', 'tantyyellow' );
								break;

							default:
								$day_num_ordinal = esc_html__( 'th', 'tantyyellow' );

						endswitch;
					}
					?>

					<!-- Current page in a breadcrumb list -->
					<li role="listitem">

						<a aria-label="
							<?php
							printf(
								/* translators: %s: The title of the current page. */
								esc_attr__( 'Current page is the archive page of the day: "%2$s %3$s %1$s"', 'tantyyellow' ),
								esc_attr( get_query_var( 'year' ) ),
								esc_attr( $GLOBALS['wp_locale']->get_month( get_query_var( 'monthnum' ) ) ),
								esc_attr( $day_num . $day_num_ordinal )
							);
							?>
						" tabindex="0">

							<?php echo esc_html( $day_num . $day_num_ordinal ); ?>

						</a>

					</li>

					<?php
				elseif ( is_month() ) :
					?>
					<li role="listitem">

						<a href="<?php echo esc_url( get_year_link( get_query_var( 'year' ) ) ); ?>" aria-label="
							<?php
							printf(
								/* translators: %s: The title of the page. */
								esc_attr__( 'Archive page of the year: "%s"', 'tantyyellow' ),
								esc_attr( get_query_var( 'year' ) )
							);
							?>
						">

							<?php echo esc_html( get_query_var( 'year' ) ); ?>
							<?php echo ( ( 'ja' === get_locale() ) ? esc_html__( 'seireki', 'tantyyellow' ) : '' ); ?>

						</a>

					</li>

					<li>&gt;</li>

					<!-- Current page in a breadcrumb list -->
					<li role="listitem">

						<a aria-label="
							<?php
							printf(
								/* translators: %s: The title of the current page. */
								esc_attr__( 'Current page is the archive page of the month: "%2$s %1$s"', 'tantyyellow' ),
								esc_attr( get_query_var( 'year' ) ),
								esc_attr( $GLOBALS['wp_locale']->get_month( get_query_var( 'monthnum' ) ) )
							);
							?>
						" tabindex="0">

							<?php echo esc_html( $GLOBALS['wp_locale']->get_month( get_query_var( 'monthnum' ) ) ); ?>

						</a>

					</li>

					<?php
				elseif ( is_year() ) :
					?>
					<!-- Current page in a breadcrumb list -->
					<li role="listitem">

						<a aria-label="
							<?php
							printf(
								/* translators: %s: The title of the page. */
								esc_attr__( 'Current page is the archive page of the year: "%s"', 'tantyyellow' ),
								esc_attr( get_query_var( 'year' ) )
							);
							?>
						" tabindex="0">

							<?php echo esc_html( get_query_var( 'year' ) ); ?>
							<?php echo ( ( 'ja' === get_locale() ) ? esc_html__( 'seireki', 'tantyyellow' ) : '' ); ?>

						</a>

					</li>

					<?php
				endif;

				/* ----- If the current page is "Category" page... -------------------------------- */
			elseif ( is_category() ) :

				$cats = get_queried_object();

				if ( 0 !== $cats->parent ) :

					$reversed_cats = array_reverse( get_ancestors( $cats->cat_ID, 'category' ) );
					foreach ( $reversed_cats as $cat ) :
						?>
					<li role="listitem">

						<a href="<?php echo esc_url( get_category_link( $cat ) ); ?>" aria-label="
							<?php
							printf(
								/* translators: %s: The title of the page. */
								esc_attr__( 'Archive page of the category: "%s"', 'tantyyellow' ),
								esc_attr( get_cat_name( $cat ) )
							);
							?>
						">

							<?php echo esc_html( get_cat_name( $cat ) ); ?>

						</a>

					</li>

					<li>&gt;</li>

						<?php
					endforeach;

				endif;
				?>

				<!-- Current page in a breadcrumb list -->
				<li role="listitem">

					<a aria-label="
						<?php
						printf(
							/* translators: %s: The title of the page. */
							esc_attr__( 'Current page is the archive page of the category: "%s"', 'tantyyellow' ),
							esc_html( $cats->cat_name )
						);
						?>
					" tabindex="0">

						<?php
						echo esc_html__( 'Category: ', 'tantyyellow' );
						echo esc_html( $cats->cat_name );
						?>

					</a>

				</li>



				<?php
				/* ----- If the current page is "Author" page... ---------------------------------- */
			elseif ( is_author() ) :
				?>
				<!-- Current page in a breadcrumb list -->
				<li role="listitem">

					<a aria-label="
					<?php
						printf(
							/* translators: %s: The title of the page. */
							esc_attr__( 'Current page is the archive page of the author: "%s"', 'tantyyellow' ),
							esc_attr( get_the_author_meta( 'display_name', get_query_var( 'author' ) ) )
						);
					?>
					" tabindex="0">

						<?php
						echo esc_html__( 'Author: ', 'tantyyellow' );
						the_author_meta( 'display_name', esc_html( get_query_var( 'author' ) ) );
						?>

					</a>

				</li>



				<?php
				/* ----- If the current page is "Single" page... ---------------------------------- */
			elseif ( is_single() ) :

				// Get the post's all cagetories.
				$single_cats = get_the_category( $post->ID );

				// If the post belongs to at least one cagetory.....
				if ( isset( $single_cats[0] ) ) :

					$single_1st_cat = $single_cats[0];

					// If the post's 1st cagetory has at least one parental category.....
					if ( 0 !== $single_1st_cat->parent ) :

						$single_1st_cat_ancestors = array_reverse( get_ancestors( $single_1st_cat->cat_ID, 'category' ) );
						foreach ( $single_1st_cat_ancestors as $cat_ancestor_each ) :
							?>
							<li role="listitem">

								<a href="<?php echo esc_url( get_category_link( $cat_ancestor_each ) ); ?>" aria-label="
									<?php
									printf(
										/* translators: %s: The title of the page. */
										esc_attr__( 'Archive page of the category: "%s"', 'tantyyellow' ),
										esc_attr( get_cat_name( $cat_ancestor_each ) )
									);
									?>
								">

									<?php echo esc_html( get_cat_name( $cat_ancestor_each ) ); ?>

								</a>

							</li>

							<li>&gt;</li>

							<?php
						endforeach;

					endif;
					?>

					<li role="listitem">

						<a href="<?php echo esc_url( get_category_link( $single_1st_cat->cat_ID ) ); ?>" aria-label="
							<?php
							printf(
								/* translators: %s: The title of the page. */
								esc_attr__( 'Archive page of the category: "%s"', 'tantyyellow' ),
								esc_attr( $single_1st_cat->cat_name )
							);
							?>
						">

							<?php echo esc_html( $single_1st_cat->cat_name ); ?>

						</a>

					</li>

					<li>&gt;</li>

					<?php
					/* ===== End of "if( isset( $single_cats[0] ))" = */
				endif;
				?>

				<!-- Current page in a breadcrumb list -->
				<li role="listitem">

					<a aria-label="
						<?php
						printf(
							/* translators: %s: The title of the page. */
							esc_attr__( 'Current page is the single post page titled: "%s"', 'tantyyellow' ),
							esc_attr( wp_strip_all_tags( $current_page_title ) )
						);
						?>
					" tabindex="0">

						<?php echo wp_kses_post( $current_page_title ); ?>

					</a>

				</li>



				<?php
				/* ----- If the current page is "Attachment" page... ------------------------------ */
			elseif ( is_attachment() ) :

				if ( 0 !== $post->post_parent ) :
					?>
					<li role="listitem">

						<a href="<?php echo esc_url( get_permalink( $post->post_parent ) ); ?>" aria-label="
							<?php
							printf(
								/* translators: %s: The title of the page. */
								esc_attr__( 'Parental page of the the attachment page titled: "%s"', 'tantyyellow' ),
								esc_attr( wp_strip_all_tags( get_the_title( $post->post_parent ) ) )
							);
							?>
						">

							<?php echo wp_kses_post( get_the_title( $post->post_parent ) ); ?>

						</a>

					</li>

					<li>&gt;</li>

					<?php
				endif;
				?>

				<!-- Current page in a breadcrumb list -->
				<li role="listitem">

					<a aria-label="
						<?php
						printf(
							/* translators: %s: The title of the current page. */
							esc_attr__( 'Current page is the attachment page titled: "%s"', 'tantyyellow' ),
							esc_attr( wp_strip_all_tags( $current_page_title ) )
						);
						?>
					" tabindex="0">

						<?php echo wp_kses_post( $current_page_title ); ?>

					</a>

				</li>



				<?php
				/* ----- If the current page is the other page... --------------------------------- */
			else :
				?>

				<!-- Current page in a breadcrumb list -->
				<li role="listitem">

					<a aria-label="
						<?php
						printf(
							/* translators: %s: The title of the current page. */
							esc_attr__( 'Current page is %s', 'tantyyellow' ),
							esc_attr( wp_strip_all_tags( get_the_title() ) )
						);
						?>
					" tabindex="0">

						<?php echo wp_kses_post( get_the_title() ); ?>

					</a>

				</li>


				<?php
				/* ----- End of "if ( is_page() )" ------------------------------------------------ */
			endif;

			/* ===== End of "if ( is_front_page() )" ==================================================== */
		endif;

	} )();
?>



	</ul><!-- /.breadcrumb_inner_ul -->
</nav><!-- /#breadcrumb -->
